@@ -121,7 +121,7 @@ class Licenses {
 
 	function outputOption( $val, $attribs = null, $depth ) {
 		$val = str_repeat( /* &nbsp */ "\xc2\xa0", $depth * 2 ) . $val;
-		return str_repeat( "\t", $depth ) . wfElement( 'option', $attribs, $val ) . "\n";
+		return str_repeat( "\t", $depth ) . Xml::element( 'option', $attribs, $val ) . "\n";
 	}
 
 	function msg( $str ) {
