@@ -3,24 +3,23 @@
 /**
  * Variant of QueryPage which formats the result as a simple link to the page
  *
- * @package MediaWiki
- * @addtogroup SpecialPage
+ * @ingroup SpecialPage
  */
 class PageQueryPage extends QueryPage {
 
 	/**
 	 * Format the result as a simple link to the page
 	 *
-	 * @param Skin $skin
-	 * @param object $row Result row
+	 * @param $skin Skin
+	 * @param $row Object: result row
 	 * @return string
 	 */
 	public function formatResult( $skin, $row ) {
 		global $wgContLang;
 		$title = Title::makeTitleSafe( $row->namespace, $row->title );
-		return $skin->makeKnownLinkObj( $title,
-			htmlspecialchars( $wgContLang->convert( $title->getPrefixedText() ) ) );
+		$text = $row->title;
+		if ($title instanceof Title)
+			$text = $wgContLang->convert( $title->getPrefixedText() ); 
+		return $skin->link( $title, htmlspecialchars($text), array(), array(), array('known', 'noclasses') );
 	}
 }
-
-
