@@ -7,6 +7,7 @@
  * License: GPL (http://www.gnu.org/copyleft/gpl.html)
  *
  * @author Gabriel Wicke <wicke@wikidev.net>
+ * @file
  */
 
 /**
@@ -20,22 +21,22 @@ class RawPage {
 	var $mContentType, $mExpandTemplates;
 
 	function __construct( &$article, $request = false ) {
-		global $wgRequest, $wgInputEncoding, $wgSquidMaxage, $wgJsMimeType, $wgForcedRawSMaxage, $wgGroupPermissions;
+		global $wgRequest, $wgInputEncoding, $wgSquidMaxage, $wgJsMimeType, $wgGroupPermissions;
 
 		$allowedCTypes = array('text/x-wiki', $wgJsMimeType, 'text/css', 'application/x-zope-edit');
 		$this->mArticle =& $article;
 		$this->mTitle =& $article->mTitle;
 
-		if ( $request === false ) {
+		if( $request === false ) {
 			$this->mRequest =& $wgRequest;
 		} else {
 			$this->mRequest = $request;
 		}
 
 		$ctype = $this->mRequest->getVal( 'ctype' );
-		$smaxage = $this->mRequest->getIntOrNull( 'smaxage', $wgSquidMaxage );
+		$smaxage = $this->mRequest->getIntOrNull( 'smaxage' );
 		$maxage = $this->mRequest->getInt( 'maxage', $wgSquidMaxage );
-		
+
 		$this->mExpandTemplates = $this->mRequest->getVal( 'templates' ) === 'expand';
 		$this->mUseMessageCache = $this->mRequest->getBool( 'usemsgcache' );
 
@@ -43,17 +44,17 @@ class RawPage {
 
 		$oldid = $this->mRequest->getInt( 'oldid' );
 
-		switch ( $wgRequest->getText( 'direction' ) ) {
+		switch( $wgRequest->getText( 'direction' ) ) {
 			case 'next':
 				# output next revision, or nothing if there isn't one
-				if ( $oldid ) {
+				if( $oldid ) {
 					$oldid = $this->mTitle->getNextRevisionId( $oldid );
 				}
 				$oldid = $oldid ? $oldid : -1;
 				break;
 			case 'prev':
 				# output previous revision, or nothing if there isn't one
-				if ( ! $oldid ) {
+				if( ! $oldid ) {
 					# get the current revision so we can get the penultimate one
 					$this->mArticle->getTouched();
 					$oldid = $this->mArticle->mLatest;
@@ -66,15 +67,15 @@ class RawPage {
 				break;
 		}
 		$this->mOldId = $oldid;
-		
+
 		# special case for 'generated' raw things: user css/js
 		$gen = $this->mRequest->getVal( 'gen' );
 
-		if($gen == 'css') {
+		if( $gen == 'css' ) {
 			$this->mGen = $gen;
 			if( is_null( $smaxage ) ) $smaxage = $wgSquidMaxage;
 			if($ctype == '') $ctype = 'text/css';
-		} elseif ($gen == 'js') {
+		} elseif( $gen == 'js' ) {
 			$this->mGen = $gen;
 			if( is_null( $smaxage ) ) $smaxage = $wgSquidMaxage;
 			if($ctype == '') $ctype = $wgJsMimeType;
@@ -82,25 +83,25 @@ class RawPage {
 			$this->mGen = false;
 		}
 		$this->mCharset = $wgInputEncoding;
-		
+
 		# Force caching for CSS and JS raw content, default: 5 minutes
-		if (is_null($smaxage) and ($ctype=='text/css' or $ctype==$wgJsMimeType)) {
+		if( is_null($smaxage) and ($ctype=='text/css' or $ctype==$wgJsMimeType) ) {
+			global $wgForcedRawSMaxage;
 			$this->mSmaxage = intval($wgForcedRawSMaxage);
 		} else {
 			$this->mSmaxage = intval( $smaxage );
 		}
 		$this->mMaxage = $maxage;
-		
-		# Output may contain user-specific data; 
+
+		# Output may contain user-specific data;
 		# vary generated content for open sessions and private wikis
-		if ($this->mGen or !$wgGroupPermissions['*']['read']) {
-			$this->mPrivateCache = ( $this->mSmaxage == 0 ) ||
-				( session_id() != '' );
+		if( $this->mGen or !$wgGroupPermissions['*']['read'] ) {
+			$this->mPrivateCache = $this->mSmaxage == 0 || session_id() != '';
 		} else {
 			$this->mPrivateCache = false;
 		}
-		
-		if ( $ctype == '' or ! in_array( $ctype, $allowedCTypes ) ) {
+
+		if( $ctype == '' or ! in_array( $ctype, $allowedCTypes ) ) {
 			$this->mContentType = 'text/x-wiki';
 		} else {
 			$this->mContentType = $ctype;
@@ -125,7 +126,16 @@ class RawPage {
 		} else {
 			$url = $_SERVER['PHP_SELF'];
 		}
-		
+
+		if( $url == '' ) {
+			# This will make the next check fail with a confusing error
+			# message, so we should mention it separately.
+			wfHttpError( 500, 'Internal Server Error',
+				"\$_SERVER['PHP_SELF'] is not set.  Perhaps you're using CGI" .
+				" and haven't set cgi.fix_pathinfo = 1 in php.ini?" );
+			return;
+		}
+
 		if( strcmp( $wgScript, $url ) ) {
 			# Internet Explorer will ignore the Content-Type header if it
 			# thinks it sees a file extension it recognizes. Make sure that
@@ -148,10 +158,22 @@ class RawPage {
 		# allow the client to cache this for 24 hours
 		$mode = $this->mPrivateCache ? 'private' : 'public';
 		header( 'Cache-Control: '.$mode.', s-maxage='.$this->mSmaxage.', max-age='.$this->mMaxage );
+		
+		if( HTMLFileCache::useFileCache() ) {
+			$cache = new HTMLFileCache( $this->mTitle, 'raw' );
+			if( $cache->isFileCacheGood( /* Assume up to date */ ) ) {
+				$cache->loadFromFileCache();
+				$wgOut->disable();
+				return;
+			} else {
+				ob_start( array(&$cache, 'saveToFileCache' ) );
+			}
+		}
+		
 		$text = $this->getRawText();
 
 		if( !wfRunHooks( 'RawPageViewBeforeOutput', array( &$this, &$text ) ) ) {
-			wfDebug( __METHOD__ . ': RawPageViewBeforeOutput hook broke raw page output.' );
+			wfDebug( __METHOD__ . ": RawPageViewBeforeOutput hook broke raw page output.\n" );
 		}
 
 		echo $text;
@@ -160,13 +182,15 @@ class RawPage {
 
 	function getRawText() {
 		global $wgUser, $wgOut, $wgRequest;
-		if($this->mGen) {
+		if( $this->mGen ) {
 			$sk = $wgUser->getSkin();
-			$sk->initPage($wgOut);
-			if($this->mGen == 'css') {
-				return $sk->getUserStylesheet();
-			} else if($this->mGen == 'js') {
-				return $sk->getUserJs();
+			if( !StubObject::isRealObject( $wgOut ) )
+				$wgOut->_unstub( 2 );
+			$sk->initPage( $wgOut );
+			if( $this->mGen == 'css' ) {
+				return $sk->generateUserStylesheet();
+			} else if( $this->mGen == 'js' ) {
+				return $sk->generateUserJs();
 			}
 		} else {
 			return $this->getArticleText();
@@ -178,7 +202,7 @@ class RawPage {
 		$text = '';
 		if( $this->mTitle ) {
 			// If it's a MediaWiki message we can just hit the message cache
-			if ( $this->mUseMessageCache && $this->mTitle->getNamespace() == NS_MEDIAWIKI ) {
+			if( $this->mUseMessageCache && $this->mTitle->getNamespace() == NS_MEDIAWIKI ) {
 				$key = $this->mTitle->getDBkey();
 				$text = wfMsgForContentNoTrans( $key );
 				# If the message doesn't exist, return a blank
@@ -188,11 +212,11 @@ class RawPage {
 			} else {
 				// Get it from the DB
 				$rev = Revision::newFromTitle( $this->mTitle, $this->mOldId );
-				if ( $rev ) {
+				if( $rev ) {
 					$lastmod = wfTimestamp( TS_RFC2822, $rev->getTimestamp() );
 					header( "Last-modified: $lastmod" );
 
-					if ( !is_null($this->mSection ) ) {
+					if( !is_null($this->mSection ) ) {
 						global $wgParser;
 						$text = $wgParser->getSection ( $rev->getText(), $this->mSection );
 					} else
@@ -210,7 +234,7 @@ class RawPage {
 			# have the pages.
 			header( "HTTP/1.0 404 Not Found" );
 		}
-		
+
 		// Special-case for empty CSS/JS
 		//
 		// Internet Explorer for Mac handles empty files badly;
@@ -224,19 +248,18 @@ class RawPage {
 				$this->mContentType == 'text/javascript' ) ) {
 			return "/* Empty */";
 		}
-		
+
 		return $this->parseArticleText( $text );
 	}
 
 	function parseArticleText( $text ) {
-		if ( $text === '' )
+		if( $text === '' )
 			return '';
 		else
-			if ( $this->mExpandTemplates ) {
+			if( $this->mExpandTemplates ) {
 				global $wgParser;
 				return $wgParser->preprocess( $text, $this->mTitle, new ParserOptions() );
 			} else
 				return $text;
 	}
 }
-
