@@ -28,6 +28,10 @@ if (!defined('MEDIAWIKI')) {
 	require_once ('ApiBase.php');
 }
 
+/**
+ * @defgroup API API
+ */
+
 /**
  * This is the main API class, used for both external and internal processing.
  * When executed, it will create the requested formatter object,
@@ -37,9 +41,9 @@ if (!defined('MEDIAWIKI')) {
  *
  * To use API from another application, run it using FauxRequest object, in which
  * case any internal exceptions will not be handled but passed up to the caller.
- * After successful execution, use getResult() for the resulting data.   
- *  
- * @addtogroup API
+ * After successful execution, use getResult() for the resulting data.
+ *
+ * @ingroup API
  */
 class ApiMain extends ApiBase {
 
@@ -61,9 +65,9 @@ class ApiMain extends ApiBase {
 		'feedwatchlist' => 'ApiFeedWatchlist',
 		'help' => 'ApiHelp',
 		'paraminfo' => 'ApiParamInfo',
-	);
-	
-	private static $WriteModules = array (
+
+		// Write modules
+		'purge' => 'ApiPurge',
 		'rollback' => 'ApiRollback',
 		'delete' => 'ApiDelete',
 		'undelete' => 'ApiUndelete',
@@ -71,8 +75,11 @@ class ApiMain extends ApiBase {
 		'block' => 'ApiBlock',
 		'unblock' => 'ApiUnblock',
 		'move' => 'ApiMove',
-		#'changerights' => 'ApiChangeRights'
-		# Disabled for now
+		'edit' => 'ApiEditPage',
+		'emailuser' => 'ApiEmailUser',
+		'watch' => 'ApiWatch',
+		'patrol' => 'ApiPatrol',
+		'import' => 'ApiImport',
 	);
 
 	/**
@@ -95,6 +102,23 @@ class ApiMain extends ApiBase {
 		'dbg' => 'ApiFormatDbg',
 		'dbgfm' => 'ApiFormatDbg'
 	);
+	
+	/**
+	 * List of user roles that are specifically relevant to the API.
+	 * array( 'right' => array ( 'msg'    => 'Some message with a $1',
+	 *                           'params' => array ( $someVarToSubst ) ),
+	 *                          );
+	 */
+	private static $mRights = array('writeapi' => array(
+						'msg' => 'Use of the write API',
+						'params' => array()
+					),
+					'apihighlimits'	=> array(
+						'msg' => 'Use higher limits in API queries (Slow queries: $1 results; Fast queries: $2 results). The limits for slow queries also apply to multivalue parameters.',
+						'params' => array (ApiMain::LIMIT_SML2, ApiMain::LIMIT_BIG2)
+					)
+	);
+
 
 	private $mPrinter, $mModules, $mModuleNames, $mFormats, $mFormatNames;
 	private $mResult, $mAction, $mShowVersions, $mEnableWrite, $mRequest, $mInternalMode, $mSquidMaxage;
@@ -113,36 +137,26 @@ class ApiMain extends ApiBase {
 		parent :: __construct($this, $this->mInternalMode ? 'main_int' : 'main');
 
 		if (!$this->mInternalMode) {
-			
+
 			// Impose module restrictions.
-			// If the current user cannot read, 
+			// If the current user cannot read,
 			// Remove all modules other than login
 			global $wgUser;
-			
+
 			if( $request->getVal( 'callback' ) !== null ) {
 				// JSON callback allows cross-site reads.
 				// For safety, strip user credentials.
 				wfDebug( "API: stripping user credentials for JSON callback\n" );
 				$wgUser = new User();
 			}
-			
-			if (!$wgUser->isAllowed('read')) {
-				self::$Modules = array(
-					'login'  => self::$Modules['login'],
-					'logout' => self::$Modules['logout'],
-					'help'   => self::$Modules['help'],
-					); 
-			}
 		}
 
-		global $wgAPIModules, $wgEnableWriteAPI; // extension modules
+		global $wgAPIModules; // extension modules
 		$this->mModules = $wgAPIModules + self :: $Modules;
-		if($wgEnableWriteAPI)
-			$this->mModules += self::$WriteModules;
 
-		$this->mModuleNames = array_keys($this->mModules); // todo: optimize
+		$this->mModuleNames = array_keys($this->mModules);
 		$this->mFormats = self :: $Formats;
-		$this->mFormatNames = array_keys($this->mFormats); // todo: optimize
+		$this->mFormatNames = array_keys($this->mFormats);
 
 		$this->mResult = new ApiResult($this);
 		$this->mShowVersions = false;
@@ -150,7 +164,8 @@ class ApiMain extends ApiBase {
 
 		$this->mRequest = & $request;
 
-		$this->mSquidMaxage = 0;
+		$this->mSquidMaxage = -1; // flag for executeActionWithErrorHandling()
+		$this->mCommit = false;
 	}
 
 	/**
@@ -175,13 +190,10 @@ class ApiMain extends ApiBase {
 	}
 
 	/**
-	 * This method will simply cause an error if the write mode was disabled for this api.
+	 * Only kept for backwards compatibility
+	 * @deprecated Use isWriteMode() instead
 	 */
-	public function requestWriteMode() {
-		if (!$this->mEnableWrite)
-			$this->dieUsage('Editing of this site is disabled. Make sure the $wgEnableWriteAPI=true; ' .
-			'statement is included in the site\'s LocalSettings.php file', 'noapiwrite');
-	}
+	public function requestWriteMode() {}
 
 	/**
 	 * Set how long the response should be cached.
@@ -194,11 +206,13 @@ class ApiMain extends ApiBase {
 	 * Create an instance of an output formatter by its name
 	 */
 	public function createPrinterByName($format) {
+		if( !isset( $this->mFormats[$format] ) )
+			$this->dieUsage( "Unrecognized format: {$format}", 'unknown_format' );
 		return new $this->mFormats[$format] ($this, $format);
 	}
 
 	/**
-	 * Execute api request. Any errors will be handled if the API was called by the remote client. 
+	 * Execute api request. Any errors will be handled if the API was called by the remote client.
 	 */
 	public function execute() {
 		$this->profileIn();
@@ -206,6 +220,7 @@ class ApiMain extends ApiBase {
 			$this->executeAction();
 		else
 			$this->executeActionWithErrorHandling();
+	
 		$this->profileOut();
 	}
 
@@ -222,6 +237,11 @@ class ApiMain extends ApiBase {
 		try {
 			$this->executeAction();
 		} catch (Exception $e) {
+			// Log it
+			if ( $e instanceof MWException ) {
+				wfDebugLog( 'exception', $e->getLogMessage() );
+			}
+
 			//
 			// Handle any kind of exception by outputing properly formatted error message.
 			// If this fails, an unhandled exception should be thrown so that global error
@@ -235,7 +255,7 @@ class ApiMain extends ApiBase {
 
 			$headerStr = 'MediaWiki-API-Error: ' . $errCode;
 			if ($e->getCode() === 0)
-				header($headerStr, true);
+				header($headerStr);
 			else
 				header($headerStr, true, $e->getCode());
 
@@ -247,11 +267,21 @@ class ApiMain extends ApiBase {
 			$this->printResult(true);
 		}
 
+		if($this->mSquidMaxage == -1)
+		{
+			# Nobody called setCacheMaxAge(), use the (s)maxage parameters
+			$smaxage = $this->getParameter('smaxage');
+			$maxage = $this->getParameter('maxage');
+		}
+		else
+			$smaxage = $maxage = $this->mSquidMaxage;
+
 		// Set the cache expiration at the last moment, as any errors may change the expiration.
 		// if $this->mSquidMaxage == 0, the expiry time is set to the first second of unix epoch
-		$expires = $this->mSquidMaxage == 0 ? 1 : time() + $this->mSquidMaxage;
+		$exp = min($smaxage, $maxage);
+		$expires = ($exp == 0 ? 1 : time() + $exp);
 		header('Expires: ' . wfTimestamp(TS_RFC2822, $expires));
-		header('Cache-Control: s-maxage=' . $this->mSquidMaxage . ', must-revalidate, max-age=0');
+		header('Cache-Control: s-maxage=' . $smaxage . ', must-revalidate, max-age=' . $maxage);
 
 		if($this->mPrinter->getIsHtml())
 			echo wfReportTime();
@@ -261,10 +291,10 @@ class ApiMain extends ApiBase {
 
 	/**
 	 * Replace the result data with the information about an exception.
-	 * Returns the error code 
+	 * Returns the error code
 	 */
 	protected function substituteResultWithError($e) {
-	
+
 			// Printer may not be initialized if the extractRequestParams() fails for the main module
 			if (!isset ($this->mPrinter)) {
 				// The printer has not been created yet. Try to manually get formatter value.
@@ -284,23 +314,35 @@ class ApiMain extends ApiBase {
 				$errMessage = array (
 				'code' => $e->getCodeString(),
 				'info' => $e->getMessage());
-				
+
 				// Only print the help message when this is for the developer, not runtime
 				if ($this->mPrinter->getIsHtml() || $this->mAction == 'help')
 					ApiResult :: setContent($errMessage, $this->makeHelpMsg());
 
 			} else {
+				global $wgShowSQLErrors, $wgShowExceptionDetails;
 				//
 				// Something is seriously wrong
 				//
+				if ( ( $e instanceof DBQueryError ) && !$wgShowSQLErrors ) {
+					$info = "Database query error";
+				} else {
+					$info = "Exception Caught: {$e->getMessage()}";
+				}
+
 				$errMessage = array (
 					'code' => 'internal_api_error_'. get_class($e),
-					'info' => "Exception Caught: {$e->getMessage()}"
+					'info' => $info,
 				);
-				ApiResult :: setContent($errMessage, "\n\n{$e->getTraceAsString()}\n\n");
+				ApiResult :: setContent($errMessage, $wgShowExceptionDetails ? "\n\n{$e->getTraceAsString()}\n\n" : "" );				
 			}
 
 			$this->getResult()->reset();
+			$this->getResult()->disableSizeCheck();
+			// Re-add the id
+			$requestid = $this->getParameter('requestid');
+			if(!is_null($requestid))
+				$this->getResult()->addValue(null, 'requestid', $requestid);
 			$this->getResult()->addValue(null, 'error', $errMessage);
 
 		return $errMessage['code'];
@@ -310,30 +352,53 @@ class ApiMain extends ApiBase {
 	 * Execute the actual module, without any error handling
 	 */
 	protected function executeAction() {
+		// First add the id to the top element
+		$requestid = $this->getParameter('requestid');
+		if(!is_null($requestid))
+			$this->getResult()->addValue(null, 'requestid', $requestid);
 
 		$params = $this->extractRequestParams();
 
 		$this->mShowVersions = $params['version'];
 		$this->mAction = $params['action'];
 
+		if( !is_string( $this->mAction ) ) {
+			$this->dieUsage( "The API requires a valid action parameter", 'unknown_action' );
+		}
+
 		// Instantiate the module requested by the user
 		$module = new $this->mModules[$this->mAction] ($this, $this->mAction);
-		
+
 		if( $module->shouldCheckMaxlag() && isset( $params['maxlag'] ) ) {
 			// Check for maxlag
-			global $wgLoadBalancer, $wgShowHostnames;
+			global $wgShowHostnames;
 			$maxLag = $params['maxlag'];
-			list( $host, $lag ) = $wgLoadBalancer->getMaxLag();
+			list( $host, $lag ) = wfGetLB()->getMaxLag();
 			if ( $lag > $maxLag ) {
+				header( 'Retry-After: ' . max( intval( $maxLag ), 5 ) );
+				header( 'X-Database-Lag: ' . intval( $lag ) );
+				// XXX: should we return a 503 HTTP error code like wfMaxlagError() does?
 				if( $wgShowHostnames ) {
-					ApiBase :: dieUsage( "Waiting for $host: $lag seconds lagged", 'maxlag' );
+					$this->dieUsage( "Waiting for $host: $lag seconds lagged", 'maxlag' );
 				} else {
-					ApiBase :: dieUsage( "Waiting for a database server: $lag seconds lagged", 'maxlag' );
+					$this->dieUsage( "Waiting for a database server: $lag seconds lagged", 'maxlag' );
 				}
 				return;
 			}
 		}
-		
+
+		global $wgUser;
+		if ($module->isReadMode() && !$wgUser->isAllowed('read'))
+			$this->dieUsageMsg(array('readrequired'));
+		if ($module->isWriteMode()) {
+			if (!$this->mEnableWrite)
+				$this->dieUsageMsg(array('writedisabled'));
+			if (!$wgUser->isAllowed('writeapi'))
+				$this->dieUsageMsg(array('writerequired'));
+			if (wfReadOnly())
+				$this->dieUsageMsg(array('readonlytext'));
+		}
+
 		if (!$this->mInternalMode) {
 			// Ignore mustBePosted() for internal calls
 			if($module->mustBePosted() && !$this->mRequest->wasPosted())
@@ -353,6 +418,7 @@ class ApiMain extends ApiBase {
 		// Execute
 		$module->profileIn();
 		$module->execute();
+		wfRunHooks('APIAfterExecute', array(&$module));
 		$module->profileOut();
 
 		if (!$this->mInternalMode) {
@@ -365,15 +431,15 @@ class ApiMain extends ApiBase {
 	 * Print results using the current printer
 	 */
 	protected function printResult($isError) {
+		$this->getResult()->cleanUpUTF8();
 		$printer = $this->mPrinter;
 		$printer->profileIn();
-	
+
 		/* If the help message is requested in the default (xmlfm) format,
 		 * tell the printer not to escape ampersands so that our links do
 		 * not break. */
-		$params = $this->extractRequestParams();
-		$printer->setUnescapeAmps ( ( $this->mAction == 'help' || $isError ) 
-				&& $params['format'] == ApiMain::API_DEFAULT_FORMAT );
+		$printer->setUnescapeAmps ( ( $this->mAction == 'help' || $isError )
+				&& $printer->getFormat() == 'XML' && $printer->getIsHtml() );
 
 		$printer->initPrinter($isError);
 
@@ -381,6 +447,10 @@ class ApiMain extends ApiBase {
 		$printer->closePrinter();
 		$printer->profileOut();
 	}
+	
+	public function isReadMode() {
+		return false;
+	}
 
 	/**
 	 * See ApiBase for description.
@@ -399,6 +469,15 @@ class ApiMain extends ApiBase {
 			'maxlag'  => array (
 				ApiBase :: PARAM_TYPE => 'integer'
 			),
+			'smaxage' => array (
+				ApiBase :: PARAM_TYPE => 'integer',
+				ApiBase :: PARAM_DFLT => 0
+			),
+			'maxage' => array (
+				ApiBase :: PARAM_TYPE => 'integer',
+				ApiBase :: PARAM_DFLT => 0
+			),
+			'requestid' => null,
 		);
 	}
 
@@ -410,7 +489,10 @@ class ApiMain extends ApiBase {
 			'format' => 'The format of the output',
 			'action' => 'What action you would like to perform',
 			'version' => 'When showing help, include version for each module',
-			'maxlag' => 'Maximum lag'
+			'maxlag' => 'Maximum lag',
+			'smaxage' => 'Set the s-maxage header to this many seconds. Errors are never cached',
+			'maxage' => 'Set the max-age header to this many seconds. Errors are never cached',
+			'requestid' => 'Request ID to distinguish requests. This will just be output back to you',
 		);
 	}
 
@@ -444,13 +526,18 @@ class ApiMain extends ApiBase {
 			'',
 		);
 	}
-	
+
 	/**
 	 * Returns an array of strings with credits for the API
 	 */
 	protected function getCredits() {
 		return array(
-			'This API is being implemented by Roan Kattouw <Firstname>.<Lastname>@home.nl',
+			'API developers:',
+			'    Roan Kattouw <Firstname>.<Lastname>@home.nl (lead developer Sep 2007-present)',
+			'    Victor Vasiliev - vasilvv at gee mail dot com',
+			'    Bryan Tong Minh - bryan . tongminh @ gmail . com',
+			'    Yuri Astrakhan <Firstname><Lastname>@gmail.com (creator, lead developer Sep 2006-Sep 2007)',
+			'',
 			'Please send your comments, suggestions and questions to mediawiki-api@lists.wikimedia.org',
 			'or file a bug report at http://bugzilla.wikimedia.org/'
 		);
@@ -460,7 +547,7 @@ class ApiMain extends ApiBase {
 	 * Override the parent to generate help messages for all available modules.
 	 */
 	public function makeHelpMsg() {
-		
+
 		$this->mPrinter->setHelp();
 
 		// Use parent to make default message for the main module
@@ -477,6 +564,14 @@ class ApiMain extends ApiBase {
 			$msg .= "\n";
 		}
 
+		$msg .= "\n$astriks Permissions $astriks\n\n";
+		foreach ( self :: $mRights as $right => $rightMsg ) {
+			$groups = User::getGroupsWithPermission( $right );
+			$msg .= "* " . $right . " *\n  " . wfMsgReplaceArgs( $rightMsg[ 'msg' ], $rightMsg[ 'params' ] ) . 
+						"\nGranted to:\n  " . str_replace( "*", "all", implode( ", ", $groups ) ) . "\n";
+
+		}
+
 		$msg .= "\n$astriks Formats  $astriks\n\n";
 		foreach( $this->mFormats as $formatName => $unused ) {
 			$module = $this->createPrinterByName($formatName);
@@ -486,25 +581,25 @@ class ApiMain extends ApiBase {
 				$msg .= $msg2;
 			$msg .= "\n";
 		}
-		
+
 		$msg .= "\n*** Credits: ***\n   " . implode("\n   ", $this->getCredits()) . "\n";
-		
+
 
 		return $msg;
 	}
 
 	public static function makeHelpMsgHeader($module, $paramName) {
 		$modulePrefix = $module->getModulePrefix();
-		if (!empty($modulePrefix))
-			$modulePrefix = "($modulePrefix) "; 
-		
+		if (strval($modulePrefix) !== '')
+			$modulePrefix = "($modulePrefix) ";
+
 		return "* $paramName={$module->getModuleName()} $modulePrefix*";
-	} 
+	}
 
 	private $mIsBot = null;
 	private $mIsSysop = null;
 	private $mCanApiHighLimits = null;
-	
+
 	/**
 	 * Returns true if the currently logged in user is a bot, false otherwise
 	 * OBSOLETE, use canApiHighLimits() instead
@@ -516,7 +611,7 @@ class ApiMain extends ApiBase {
 		}
 		return $this->mIsBot;
 	}
-	
+
 	/**
 	 * Similar to isBot(), this method returns true if the logged in user is
 	 * a sysop, and false if not.
@@ -530,7 +625,11 @@ class ApiMain extends ApiBase {
 
 		return $this->mIsSysop;
 	}
-	
+
+	/**
+	 * Check whether the current user is allowed to use high limits
+	 * @return bool
+	 */
 	public function canApiHighLimits() {
 		if (!isset($this->mCanApiHighLimits)) {
 			global $wgUser;
@@ -540,6 +639,10 @@ class ApiMain extends ApiBase {
 		return $this->mCanApiHighLimits;
 	}
 
+	/**
+	 * Check whether the user wants us to show version information in the API help
+	 * @return bool
+	 */
 	public function getShowVersions() {
 		return $this->mShowVersions;
 	}
@@ -550,8 +653,8 @@ class ApiMain extends ApiBase {
 	 */
 	public function getVersion() {
 		$vers = array ();
-		$vers[] = 'MediaWiki ' . SpecialVersion::getVersion();
-		$vers[] = __CLASS__ . ': $Id: ApiMain.php 31484 2008-03-03 05:46:20Z brion $';
+		$vers[] = 'MediaWiki: ' . SpecialVersion::getVersion() . "\n    http://svn.wikimedia.org/viewvc/mediawiki/trunk/phase3/";
+		$vers[] = __CLASS__ . ': $Id: ApiMain.php 50834 2009-05-20 20:10:47Z catrope $';
 		$vers[] = ApiBase :: getBaseVersion();
 		$vers[] = ApiFormatBase :: getBaseVersion();
 		$vers[] = ApiQueryBase :: getBaseVersion();
@@ -561,7 +664,7 @@ class ApiMain extends ApiBase {
 
 	/**
 	 * Add or overwrite a module in this ApiMain instance. Intended for use by extending
-	 * classes who wish to add their own modules to their lexicon or override the 
+	 * classes who wish to add their own modules to their lexicon or override the
 	 * behavior of inherent ones.
 	 *
 	 * @access protected
@@ -583,7 +686,7 @@ class ApiMain extends ApiBase {
 	protected function addFormat( $fmtName, $fmtClass ) {
 		$this->mFormats[$fmtName] = $fmtClass;
 	}
-	
+
 	/**
 	 * Get the array mapping module names to class names
 	 */
@@ -595,8 +698,8 @@ class ApiMain extends ApiBase {
 /**
  * This exception will be thrown when dieUsage is called to stop module execution.
  * The exception handling code will print a help screen explaining how this API may be used.
- * 
- * @addtogroup API
+ *
+ * @ingroup API
  */
 class UsageException extends Exception {
 
@@ -613,5 +716,3 @@ class UsageException extends Exception {
 		return "{$this->getCodeString()}: {$this->getMessage()}";
 	}
 }
-
-
