@@ -29,15 +29,15 @@ if (!defined('MEDIAWIKI')) {
 }
 
 /**
- * This is the main query class. It behaves similar to ApiMain: based on the parameters given,
- * it will create a list of titles to work on (an instance of the ApiPageSet object)
- * instantiate and execute various property/list/meta modules,
- * and assemble all resulting data into a single ApiResult object.
- * 
- * In the generator mode, a generator will be first executed to populate a second ApiPageSet object,
- * and that object will be used for all subsequent modules.
- * 
- * @addtogroup API
+ * This is the main query class. It behaves similar to ApiMain: based on the
+ * parameters given, it will create a list of titles to work on (an ApiPageSet
+ * object), instantiate and execute various property/list/meta modules, and
+ * assemble all resulting data into a single ApiResult object.
+ *
+ * In generator mode, a generator will be executed first to populate a second
+ * ApiPageSet object, and that object will be used for all subsequent modules.
+ *
+ * @ingroup API
  */
 class ApiQuery extends ApiBase {
 
@@ -55,9 +55,12 @@ class ApiQuery extends ApiBase {
 		'templates' => 'ApiQueryLinks',
 		'categories' => 'ApiQueryCategories',
 		'extlinks' => 'ApiQueryExternalLinks',
+		'categoryinfo' => 'ApiQueryCategoryInfo',
+		'duplicatefiles' => 'ApiQueryDuplicateFiles',
 	);
 
 	private $mQueryListModules = array (
+		'allimages' => 'ApiQueryAllimages',
 		'allpages' => 'ApiQueryAllpages',
 		'alllinks' => 'ApiQueryAllLinks',
 		'allcategories' => 'ApiQueryAllCategories',
@@ -73,9 +76,11 @@ class ApiQuery extends ApiBase {
 		'search' => 'ApiQuerySearch',
 		'usercontribs' => 'ApiQueryContributions',
 		'watchlist' => 'ApiQueryWatchlist',
+		'watchlistraw' => 'ApiQueryWatchlistRaw',
 		'exturlusage' => 'ApiQueryExtLinksUsage',
 		'users' => 'ApiQueryUsers',
 		'random' => 'ApiQueryRandom',
+		'protectedtitles' => 'ApiQueryProtectedTitles',
 	);
 
 	private $mQueryMetaModules = array (
@@ -90,11 +95,11 @@ class ApiQuery extends ApiBase {
 	public function __construct($main, $action) {
 		parent :: __construct($main, $action);
 
-		// Allow custom modules to be added in LocalSettings.php		
-		global $wgApiQueryPropModules, $wgApiQueryListModules, $wgApiQueryMetaModules;
-		self :: appendUserModules($this->mQueryPropModules, $wgApiQueryPropModules);
-		self :: appendUserModules($this->mQueryListModules, $wgApiQueryListModules);
-		self :: appendUserModules($this->mQueryMetaModules, $wgApiQueryMetaModules);
+		// Allow custom modules to be added in LocalSettings.php
+		global $wgAPIPropModules, $wgAPIListModules, $wgAPIMetaModules;
+		self :: appendUserModules($this->mQueryPropModules, $wgAPIPropModules);
+		self :: appendUserModules($this->mQueryListModules, $wgAPIListModules);
+		self :: appendUserModules($this->mQueryMetaModules, $wgAPIMetaModules);
 
 		$this->mPropModuleNames = array_keys($this->mQueryPropModules);
 		$this->mListModuleNames = array_keys($this->mQueryListModules);
@@ -107,6 +112,8 @@ class ApiQuery extends ApiBase {
 
 	/**
 	 * Helper function to append any add-in modules to the list
+	 * @param $modules array Module array
+	 * @param $newModules array Module array to add to $modules
 	 */
 	private static function appendUserModules(&$modules, $newModules) {
 		if (is_array( $newModules )) {
@@ -118,11 +125,12 @@ class ApiQuery extends ApiBase {
 
 	/**
 	 * Gets a default slave database connection object
+	 * @return Database
 	 */
 	public function getDB() {
 		if (!isset ($this->mSlaveDB)) {
 			$this->profileDBIn();
-			$this->mSlaveDB = wfGetDB(DB_SLAVE);
+			$this->mSlaveDB = wfGetDB(DB_SLAVE,'api');
 			$this->profileDBOut();
 		}
 		return $this->mSlaveDB;
@@ -130,9 +138,13 @@ class ApiQuery extends ApiBase {
 
 	/**
 	 * Get the query database connection with the given name.
-	 * If no such connection has been requested before, it will be created. 
-	 * Subsequent calls with the same $name will return the same connection 
-	 * as the first, regardless of $db or $groups new values. 
+	 * If no such connection has been requested before, it will be created.
+	 * Subsequent calls with the same $name will return the same connection
+	 * as the first, regardless of the values of $db and $groups
+	 * @param $name string Name to assign to the database connection
+	 * @param $db int One of the DB_* constants
+	 * @param $groups array Query groups
+	 * @return Database
 	 */
 	public function getNamedDB($name, $db, $groups) {
 		if (!array_key_exists($name, $this->mNamedDB)) {
@@ -145,33 +157,45 @@ class ApiQuery extends ApiBase {
 
 	/**
 	 * Gets the set of pages the user has requested (or generated)
+	 * @return ApiPageSet
 	 */
 	public function getPageSet() {
 		return $this->mPageSet;
 	}
-	
+
 	/**
 	 * Get the array mapping module names to class names
+	 * @return array(modulename => classname)
 	 */
 	function getModules() {
 		return array_merge($this->mQueryPropModules, $this->mQueryListModules, $this->mQueryMetaModules);
 	}
+	
+	public function getCustomPrinter() {
+		// If &exportnowrap is set, use the raw formatter
+		if ($this->getParameter('export') &&
+				$this->getParameter('exportnowrap'))
+			return new ApiFormatRaw($this->getMain(),
+				$this->getMain()->createPrinterByName('xml'));
+		else
+			return null;
+	}
 
 	/**
 	 * Query execution happens in the following steps:
 	 * #1 Create a PageSet object with any pages requested by the user
-	 * #2 If using generator, execute it to get a new PageSet object
-	 * #3 Instantiate all requested modules. 
+	 * #2 If using a generator, execute it to get a new ApiPageSet object
+	 * #3 Instantiate all requested modules.
 	 *    This way the PageSet object will know what shared data is required,
-	 *    and minimize DB calls. 
+	 *    and minimize DB calls.
 	 * #4 Output all normalization and redirect resolution information
 	 * #5 Execute all requested modules
 	 */
 	public function execute() {
-		
+
 		$this->params = $this->extractRequestParams();
 		$this->redirects = $this->params['redirects'];
-		
+
 		//
 		// Create PageSet
 		//
@@ -186,7 +210,7 @@ class ApiQuery extends ApiBase {
 		$this->InstantiateModules($modules, 'meta', $this->mQueryMetaModules);
 
 		//
-		// If given, execute generator to substitute user supplied data with generated data.  
+		// If given, execute generator to substitute user supplied data with generated data.
 		//
 		if (isset ($this->params['generator'])) {
 			$this->executeGeneratorModule($this->params['generator'], $modules);
@@ -207,41 +231,52 @@ class ApiQuery extends ApiBase {
 		foreach ($modules as $module) {
 			$module->profileIn();
 			$module->execute();
+			wfRunHooks('APIQueryAfterExecute', array(&$module));
 			$module->profileOut();
 		}
 	}
-	
+
 	/**
 	 * Query modules may optimize data requests through the $this->getPageSet() object
 	 * by adding extra fields from the page table.
-	 * This function will gather all the extra request fields from the modules. 
+	 * This function will gather all the extra request fields from the modules.
+	 * @param $modules array of module objects
+	 * @param $pageSet ApiPageSet
 	 */
 	private function addCustomFldsToPageSet($modules, $pageSet) {
-		// Query all requested modules. 
+		// Query all requested modules.
 		foreach ($modules as $module) {
 			$module->requestExtraData($pageSet);
 		}
 	}
 
 	/**
-	 * Create instances of all modules requested by the client 
+	 * Create instances of all modules requested by the client
+	 * @param $modules array to append instatiated modules to
+	 * @param $param string Parameter name to read modules from
+	 * @param $moduleList array(modulename => classname)
 	 */
 	private function InstantiateModules(&$modules, $param, $moduleList) {
-		$list = $this->params[$param];
-		if (isset ($list))
+		$list = @$this->params[$param];
+		if (!is_null ($list))
 			foreach ($list as $moduleName)
 				$modules[] = new $moduleList[$moduleName] ($this, $moduleName);
 	}
 
 	/**
-	 * Appends an element for each page in the current pageSet with the most general
-	 * information (id, title), plus any title normalizations and missing title/pageids/revids.
+	 * Appends an element for each page in the current pageSet with the
+	 * most general information (id, title), plus any title normalizations
+	 * and missing or invalid title/pageids/revids.
 	 */
 	private function outputGeneralPageInfo() {
 
 		$pageSet = $this->getPageSet();
 		$result = $this->getResult();
 
+		# We don't check for a full result set here because we can't be adding
+		# more than 380K. The maximum revision size is in the megabyte range,
+		# and the maximum result size must be even higher than that.
+
 		// Title normalizations
 		$normValues = array ();
 		foreach ($pageSet->getNormalizedTitles() as $rawTitleStr => $titleStr) {
@@ -251,11 +286,11 @@ class ApiQuery extends ApiBase {
 			);
 		}
 
-		if (!empty ($normValues)) {
+		if (count($normValues)) {
 			$result->setIndexedTagName($normValues, 'n');
 			$result->addValue('query', 'normalized', $normValues);
 		}
-		
+
 		// Interwiki titles
 		$intrwValues = array ();
 		foreach ($pageSet->getInterwikiTitles() as $rawTitleStr => $interwikiStr) {
@@ -265,21 +300,21 @@ class ApiQuery extends ApiBase {
 			);
 		}
 
-		if (!empty ($intrwValues)) {
+		if (count($intrwValues)) {
 			$result->setIndexedTagName($intrwValues, 'i');
 			$result->addValue('query', 'interwiki', $intrwValues);
 		}
-		
+
 		// Show redirect information
 		$redirValues = array ();
 		foreach ($pageSet->getRedirectTitles() as $titleStrFrom => $titleStrTo) {
 			$redirValues[] = array (
-				'from' => $titleStrFrom,
+				'from' => strval($titleStrFrom),
 				'to' => $titleStrTo
 			);
 		}
 
-		if (!empty ($redirValues)) {
+		if (count($redirValues)) {
 			$result->setIndexedTagName($redirValues, 'r');
 			$result->addValue('query', 'redirects', $redirValues);
 		}
@@ -288,7 +323,7 @@ class ApiQuery extends ApiBase {
 		// Missing revision elements
 		//
 		$missingRevIDs = $pageSet->getMissingRevisionIDs();
-		if (!empty ($missingRevIDs)) {
+		if (count($missingRevIDs)) {
 			$revids = array ();
 			foreach ($missingRevIDs as $revid) {
 				$revids[$revid] = array (
@@ -311,7 +346,9 @@ class ApiQuery extends ApiBase {
 			$vals['missing'] = '';
 			$pages[$fakeId] = $vals;
 		}
-
+		// Report any invalid titles
+		foreach ($pageSet->getInvalidTitles() as $fakeId => $title)
+			$pages[$fakeId] = array('title' => $title, 'invalid' => '');
 		// Report any missing page ids
 		foreach ($pageSet->getMissingPageIDs() as $pageid) {
 			$pages[$pageid] = array (
@@ -328,8 +365,8 @@ class ApiQuery extends ApiBase {
 			$pages[$pageid] = $vals;
 		}
 
-		if (!empty ($pages)) {
-			
+		if (count($pages)) {
+
 			if ($this->params['indexpageids']) {
 				$pageIDs = array_keys($pages);
 				// json treats all map keys as strings - converting to match
@@ -337,14 +374,45 @@ class ApiQuery extends ApiBase {
 				$result->setIndexedTagName($pageIDs, 'id');
 				$result->addValue('query', 'pageids', $pageIDs);
 			}
-						
+
 			$result->setIndexedTagName($pages, 'page');
-			$result->addValue('query', 'pages', $pages);
+			$result->addValue('query', 'pages', $pages);			
+		}
+		if ($this->params['export']) {
+			$exporter = new WikiExporter($this->getDB());
+			// WikiExporter writes to stdout, so catch its
+			// output with an ob
+			ob_start();
+			$exporter->openStream();
+			foreach (@$pageSet->getGoodTitles() as $title)
+				if ($title->userCanRead())
+					$exporter->pageByTitle($title);
+			$exporter->closeStream();
+			$exportxml = ob_get_contents();
+			ob_end_clean();
+			// Don't check the size of exported stuff
+			// It's not continuable, so it would cause more
+			// problems than it'd solve
+			$result->disableSizeCheck();
+			if ($this->params['exportnowrap']) {
+				$result->reset();
+				// Raw formatter will handle this
+				$result->addValue(null, 'text', $exportxml);
+				$result->addValue(null, 'mime', 'text/xml');
+			} else {
+				$r = array();
+				ApiResult::setContent($r, $exportxml);
+				$result->addValue('query', 'export', $r);
+			}
+			$result->enableSizeCheck();
 		}
 	}
 
 	/**
-	 * For generator mode, execute generator, and use its output as new pageSet 
+	 * For generator mode, execute generator, and use its output as new
+	 * ApiPageSet
+	 * @param $generatorName string Module name
+	 * @param $modules array of module objects
 	 */
 	protected function executeGeneratorModule($generatorName, $modules) {
 
@@ -357,7 +425,7 @@ class ApiQuery extends ApiBase {
 			ApiBase :: dieDebug(__METHOD__, "Unknown generator=$generatorName");
 		}
 
-		// Generator results 
+		// Generator results
 		$resultPageSet = new ApiPageSet($this, $this->redirects);
 
 		// Create and execute the generator
@@ -377,6 +445,7 @@ class ApiQuery extends ApiBase {
 		// populate resultPageSet with the generator output
 		$generator->profileIn();
 		$generator->executeGenerator($resultPageSet);
+		wfRunHooks('APIQueryGeneratorAfterExecute', array(&$generator, &$resultPageSet));
 		$resultPageSet->finishPageSetGeneration();
 		$generator->profileOut();
 
@@ -384,10 +453,6 @@ class ApiQuery extends ApiBase {
 		$this->mPageSet = $resultPageSet;
 	}
 
-	/**
-	 * Returns the list of allowed parameters for this module.
-	 * Qurey module also lists all ApiPageSet parameters as its own. 
-	 */
 	public function getAllowedParams() {
 		return array (
 			'prop' => array (
@@ -407,11 +472,14 @@ class ApiQuery extends ApiBase {
 			),
 			'redirects' => false,
 			'indexpageids' => false,
+			'export' => false,
+			'exportnowrap' => false,
 		);
 	}
 
 	/**
 	 * Override the parent to generate help messages for all available query modules.
+	 * @return string
 	 */
 	public function makeHelpMsg() {
 
@@ -423,12 +491,14 @@ class ApiQuery extends ApiBase {
 		$this->mAllowedGenerators = array();	// Will be repopulated
 
 		$astriks = str_repeat('--- ', 8);
+		$astriks2 = str_repeat('*** ', 10);
 		$msg .= "\n$astriks Query: Prop  $astriks\n\n";
 		$msg .= $this->makeHelpMsgHelper($this->mQueryPropModules, 'prop');
 		$msg .= "\n$astriks Query: List  $astriks\n\n";
 		$msg .= $this->makeHelpMsgHelper($this->mQueryListModules, 'list');
 		$msg .= "\n$astriks Query: Meta  $astriks\n\n";
 		$msg .= $this->makeHelpMsgHelper($this->mQueryMetaModules, 'meta');
+		$msg .= "\n\n$astriks2 Modules: continuation  $astriks2\n\n";
 
 		// Perform the base call last because the $this->mAllowedGenerators
 		// will be updated inside makeHelpMsgHelper()
@@ -440,10 +510,13 @@ class ApiQuery extends ApiBase {
 
 	/**
 	 * For all modules in $moduleList, generate help messages and join them together
+	 * @param $moduleList array(modulename => classname)
+	 * @param $paramName string Parameter name
+	 * @return string
 	 */
 	private function makeHelpMsgHelper($moduleList, $paramName) {
 
-		$moduleDscriptions = array ();
+		$moduleDescriptions = array ();
 
 		foreach ($moduleList as $moduleName => $moduleClass) {
 			$module = new $moduleClass ($this, $moduleName, null);
@@ -456,21 +529,21 @@ class ApiQuery extends ApiBase {
 				$this->mAllowedGenerators[] = $moduleName;
 				$msg .= "Generator:\n  This module may be used as a generator\n";
 			}
-			$moduleDscriptions[] = $msg;
+			$moduleDescriptions[] = $msg;
 		}
 
-		return implode("\n", $moduleDscriptions);
+		return implode("\n", $moduleDescriptions);
 	}
 
 	/**
 	 * Override to add extra parameters from PageSet
+	 * @return string
 	 */
 	public function makeHelpMsgParameters() {
 		$psModule = new ApiPageSet($this);
 		return $psModule->makeHelpMsgParameters() . parent :: makeHelpMsgParameters();
 	}
-	
-	// @todo should work correctly
+
 	public function shouldCheckMaxlag() {
 		return true;
 	}
@@ -480,32 +553,35 @@ class ApiQuery extends ApiBase {
 			'prop' => 'Which properties to get for the titles/revisions/pageids',
 			'list' => 'Which lists to get',
 			'meta' => 'Which meta data to get about the site',
-			'generator' => 'Use the output of a list as the input for other prop/list/meta items',
+			'generator' => array('Use the output of a list as the input for other prop/list/meta items',
+					'NOTE: generator parameter names must be prefixed with a \'g\', see examples.'),
 			'redirects' => 'Automatically resolve redirects',
-			'indexpageids' => 'Include an additional pageids section listing all returned page IDs.'
+			'indexpageids' => 'Include an additional pageids section listing all returned page IDs.',
+			'export' => 'Export the current revisions of all given or generated pages',
+			'exportnowrap' => 'Return the export XML without wrapping it in an XML result (same format as Special:Export). Can only be used with export',
 		);
 	}
 
 	public function getDescription() {
 		return array (
 			'Query API module allows applications to get needed pieces of data from the MediaWiki databases,',
-			'and is loosely based on the Query API interface currently available on all MediaWiki servers.',
+			'and is loosely based on the old query.php interface.',
 			'All data modifications will first have to use query to acquire a token to prevent abuse from malicious sites.'
 		);
 	}
 
 	protected function getExamples() {
 		return array (
-			'api.php?action=query&prop=revisions&meta=siteinfo&titles=Main%20Page&rvprop=user|comment'
+			'api.php?action=query&prop=revisions&meta=siteinfo&titles=Main%20Page&rvprop=user|comment',
+			'api.php?action=query&generator=allpages&gapprefix=API/&prop=revisions',
 		);
 	}
 
 	public function getVersion() {
 		$psModule = new ApiPageSet($this);
 		$vers = array ();
-		$vers[] = __CLASS__ . ': $Id: ApiQuery.php 30222 2008-01-28 19:05:26Z catrope $';
+		$vers[] = __CLASS__ . ': $Id: ApiQuery.php 48629 2009-03-20 11:40:54Z catrope $';
 		$vers[] = $psModule->getVersion();
 		return $vers;
 	}
-}
-
+}
\ No newline at end of file
