@@ -30,8 +30,8 @@ if (!defined('MEDIAWIKI')) {
 
 /**
  * Query action to List the log events, with optional filtering by various parameters.
- *  
- * @addtogroup API
+ *
+ * @ingroup API
  */
 class ApiQueryLogEvents extends ApiQueryBase {
 
@@ -40,7 +40,7 @@ class ApiQueryLogEvents extends ApiQueryBase {
 	}
 
 	public function execute() {
-		$params = $this->extractRequestParams();		
+		$params = $this->extractRequestParams();
 		$db = $this->getDB();
 
 		$prop = $params['prop'];
@@ -54,19 +54,29 @@ class ApiQueryLogEvents extends ApiQueryBase {
 
 		list($tbl_logging, $tbl_page, $tbl_user) = $db->tableNamesN('logging', 'page', 'user');
 
+		$hideLogs = LogEventsList::getExcludeClause($db);
+		if($hideLogs !== false)
+			$this->addWhere($hideLogs);
+
+		// Order is significant here
+		$this->addTables(array('logging', 'user', 'page'));
 		$this->addOption('STRAIGHT_JOIN');
-		$this->addTables("$tbl_logging LEFT OUTER JOIN $tbl_page ON " .
-		"log_namespace=page_namespace AND log_title=page_title " .
-		"INNER JOIN $tbl_user ON user_id=log_user");
+		$this->addJoinConds(array(
+			'user' => array('JOIN',
+				'user_id=log_user'),
+			'page' => array('LEFT JOIN',
+				array(	'log_namespace=page_namespace',
+					'log_title=page_title'))));
+		$index = 'times'; // default, may change
 
 		$this->addFields(array (
 			'log_type',
 			'log_action',
 			'log_timestamp',
+			'log_deleted',
 		));
-		
-		// FIXME: Fake out log_id for now until the column is live on Wikimedia
-		// $this->addFieldsIf('log_id', $this->fld_ids);
+
+		$this->addFieldsIf('log_id', $this->fld_ids);
 		$this->addFieldsIf('page_id', $this->fld_ids);
 		$this->addFieldsIf('log_user', $this->fld_user);
 		$this->addFieldsIf('user_name', $this->fld_user);
@@ -75,9 +85,11 @@ class ApiQueryLogEvents extends ApiQueryBase {
 		$this->addFieldsIf('log_comment', $this->fld_comment);
 		$this->addFieldsIf('log_params', $this->fld_details);
 		
-
-		$this->addWhereFld('log_deleted', 0);
-		$this->addWhereFld('log_type', $params['type']);
+		if( !is_null($params['type']) ) {
+			$this->addWhereFld('log_type', $params['type']);
+			$index = 'type_time';
+		}
+		
 		$this->addWhereRange('log_timestamp', $params['dir'], $params['start'], $params['end']);
 
 		$limit = $params['limit'];
@@ -85,12 +97,11 @@ class ApiQueryLogEvents extends ApiQueryBase {
 
 		$user = $params['user'];
 		if (!is_null($user)) {
-			$userid = $db->selectField('user', 'user_id', array (
-				'user_name' => $user
-			));
+			$userid = User::idFromName($user);
 			if (!$userid)
 				$this->dieUsage("User name $user not found", 'param_user');
 			$this->addWhereFld('log_user', $userid);
+			$index = 'user_time';
 		}
 
 		$title = $params['title'];
@@ -100,9 +111,21 @@ class ApiQueryLogEvents extends ApiQueryBase {
 				$this->dieUsage("Bad title value '$title'", 'param_title');
 			$this->addWhereFld('log_namespace', $titleObj->getNamespace());
 			$this->addWhereFld('log_title', $titleObj->getDBkey());
+
+			// Use the title index in preference to the user index if there is a conflict
+			$index = is_null($user) ? 'page_time' : array('page_time','user_time');
+		}
+
+		$this->addOption( 'USE INDEX', array( 'logging' => $index ) );
+
+		// Paranoia: avoid brute force searches (bug 17342)
+		if (!is_null($title)) {
+			$this->addWhere('log_deleted & ' . LogPage::DELETED_ACTION . ' = 0');
+		}
+		if (!is_null($user)) {
+			$this->addWhere('log_deleted & ' . LogPage::DELETED_USER . ' = 0');
 		}
 
-		$data = array ();
 		$count = 0;
 		$res = $this->select(__METHOD__);
 		while ($row = $db->fetchObject($res)) {
@@ -113,87 +136,117 @@ class ApiQueryLogEvents extends ApiQueryBase {
 			}
 
 			$vals = $this->extractRowInfo($row);
-			if($vals)
-				$data[] = $vals;
+			if(!$vals)
+				continue;
+			$fit = $this->getResult()->addValue(array('query', $this->getModuleName()), null, $vals);
+			if(!$fit)
+			{
+				$this->setContinueEnumParameter('start', wfTimestamp(TS_ISO_8601, $row->log_timestamp));
+				break;
+			}
 		}
 		$db->freeResult($res);
 
-		$this->getResult()->setIndexedTagName($data, 'item');
-		$this->getResult()->addValue('query', $this->getModuleName(), $data);
+		$this->getResult()->setIndexedTagName_internal(array('query', $this->getModuleName()), 'item');
+	}
+	
+	public static function addLogParams($result, &$vals, $params, $type, $ts) {
+		$params = explode("\n", $params);
+		switch ($type) {
+			case 'move':
+				if (isset ($params[0])) {
+					$title = Title :: newFromText($params[0]);
+					if ($title) {
+						$vals2 = array();
+						ApiQueryBase :: addTitleInfo($vals2, $title, "new_");
+						$vals[$type] = $vals2;
+					}
+				}
+				if (isset ($params[1]) && $params[1]) {
+					$vals[$type]['suppressedredirect'] = '';
+				} 
+				$params = null;
+				break;
+			case 'patrol':
+				$vals2 = array();
+				list( $vals2['cur'], $vals2['prev'], $vals2['auto'] ) = $params;
+				$vals[$type] = $vals2;
+				$params = null;
+				break;
+			case 'rights':
+				$vals2 = array();
+				list( $vals2['old'], $vals2['new'] ) = $params;
+				$vals[$type] = $vals2;
+				$params = null;
+				break;
+			case 'block':
+				$vals2 = array();
+				list( $vals2['duration'], $vals2['flags'] ) = $params;
+				$vals2['expiry'] = wfTimestamp(TS_ISO_8601,
+						strtotime($params[0], wfTimestamp(TS_UNIX, $ts)));
+				$vals[$type] = $vals2;
+				$params = null;
+				break;
+		}
+		if (!is_null($params)) {
+			$result->setIndexedTagName($params, 'param');
+			$vals = array_merge($vals, $params);
+		}
+		return $vals;
 	}
 
 	private function extractRowInfo($row) {
 		$vals = array();
 
 		if ($this->fld_ids) {
-			// FIXME: Fake out log_id for now until the column is live on Wikimedia
-			// $vals['logid'] = intval($row->log_id);
-			$vals['logid'] = 0;
+			$vals['logid'] = intval($row->log_id);
 			$vals['pageid'] = intval($row->page_id);
 		}
-		
+
 		if ($this->fld_title) {
-			$title = Title :: makeTitle($row->log_namespace, $row->log_title);
-			ApiQueryBase :: addTitleInfo($vals, $title);
+			if (LogEventsList::isDeleted($row, LogPage::DELETED_ACTION)) {
+				$vals['actionhidden'] = '';
+			} else {
+				$title = Title :: makeTitle($row->log_namespace, $row->log_title);
+				ApiQueryBase :: addTitleInfo($vals, $title);
+			}
 		}
-		
+
 		if ($this->fld_type) {
 			$vals['type'] = $row->log_type;
 			$vals['action'] = $row->log_action;
 		}
-		
+
 		if ($this->fld_details && $row->log_params !== '') {
-			$params = explode("\n", $row->log_params);
-			switch ($row->log_type) {
-				case 'move': 
-					if (isset ($params[0])) {
-						$title = Title :: newFromText($params[0]);
-						if ($title) {
-							$vals2 = array();
-							ApiQueryBase :: addTitleInfo($vals2, $title, "new_");
-							$vals[$row->log_type] = $vals2;
-							$params = null;
-						}
-					}
-					break;
-				case 'patrol':
-					$vals2 = array();
-					list( $vals2['cur'], $vals2['prev'], $vals2['auto'] ) = $params;
-					$vals[$row->log_type] = $vals2;
-					$params = null;
-					break;
-				case 'rights':
-					$vals2 = array();
-					list( $vals2['old'], $vals2['new'] ) = $params;
-					$vals[$row->log_type] = $vals2;
-					$params = null;
-					break;
-				case 'block':
-					$vals2 = array();
-					list( $vals2['duration'], $vals2['flags'] ) = $params;
-					$vals[$row->log_type] = $vals2;
-					$params = null;
-					break;
-			}
-			
-			if (isset($params)) {
-				$this->getResult()->setIndexedTagName($params, 'param');
-				$vals = array_merge($vals, $params);
+			if (LogEventsList::isDeleted($row, LogPage::DELETED_ACTION)) {
+				$vals['actionhidden'] = '';
+			} else {
+				self::addLogParams($this->getResult(), $vals,
+					$row->log_params, $row->log_type,
+					$row->log_timestamp);
 			}
 		}
 
 		if ($this->fld_user) {
-			$vals['user'] = $row->user_name;
-			if(!$row->log_user)
-				$vals['anon'] = '';
+			if (LogEventsList::isDeleted($row, LogPage::DELETED_USER)) {
+				$vals['userhidden'] = '';
+			} else {
+				$vals['user'] = $row->user_name;
+				if(!$row->log_user)
+					$vals['anon'] = '';
+			}
 		}
 		if ($this->fld_timestamp) {
 			$vals['timestamp'] = wfTimestamp(TS_ISO_8601, $row->log_timestamp);
 		}
-		if ($this->fld_comment && !empty ($row->log_comment)) {
-			$vals['comment'] = $row->log_comment;
+		if ($this->fld_comment && isset($row->log_comment)) {
+			if (LogEventsList::isDeleted($row, LogPage::DELETED_COMMENT)) {
+				$vals['commenthidden'] = '';
+			} else {
+				$vals['comment'] = $row->log_comment;
+			}
 		}
-			
+
 		return $vals;
 	}
 
@@ -215,7 +268,6 @@ class ApiQueryLogEvents extends ApiQueryBase {
 				)
 			),
 			'type' => array (
-				ApiBase :: PARAM_ISMULTI => true,
 				ApiBase :: PARAM_TYPE => $wgLogTypes
 			),
 			'start' => array (
@@ -267,7 +319,6 @@ class ApiQueryLogEvents extends ApiQueryBase {
 	}
 
 	public function getVersion() {
-		return __CLASS__ . ': $Id: ApiQueryLogEvents.php 30222 2008-01-28 19:05:26Z catrope $';
+		return __CLASS__ . ': $Id: ApiQueryLogEvents.php 47904 2009-03-01 11:02:49Z catrope $';
 	}
 }
-
