@@ -1,9 +1,13 @@
 <?php
 /** Achinese (Acèh)
+ *
+ * See MessagesQqq.php for message documentation incl. usage of parameters
+ * To improve a translation please visit http://translatewiki.net
  *
  * @ingroup Language
  * @file
  *
+ * @author Abi Azkia
  * @author Andri.h
  * @author Meno25
  * @author Si Gam Acèh
@@ -12,6 +16,13 @@
 $fallback = 'id';
 
 $messages = array(
+# User preference toggles
+'tog-watchlisthideown'   => 'Peusöm nyang lôn andam nibak dapeuta keunalön',
+'tog-watchlisthidebots'  => 'Peusöm nyang teu andam nibak sagoö nyang bak dapeuta keunalön',
+'tog-watchlisthideminor' => 'Peusöm Andam Bacut bak dapeuta keunalön',
+'tog-watchlisthideliu'   => 'Peusöm andam nyang nguy nyang tamöng nibak dapeuta keunalön',
+'tog-watchlisthideanons' => 'Peusöm andam nyang nguy hana taturi nibak dapeuta keunalön',
+
 # Dates
 'sun'           => 'Aleu',
 'mon'           => 'Seun',
@@ -58,18 +69,23 @@ $messages = array(
 'dec'           => 'Dub',
 
 # Categories related messages
+'pagecategories'         => '{{PLURAL:$1|Kawan|Kawan}}',
 'category_header'        => 'Teunuléh lam kawan "$1"',
 'subcategories'          => 'Subkategori',
 'category-media-header'  => 'Alat lam kawan "$1"',
 'category-empty'         => "''Kawan nyoë jinoë hat hana teunuléh atawa media.''",
+'hidden-categories'      => '{{PLURAL:$1|Kawan teusom|Kawan teusom}}',
+'category-subcat-count'  => '{{PLURAL:$2|Kawan nyoë  cit na saboh yupkawan nyoë.|Kawan nyoë na {{PLURAL:$1|yupkawan|$1 yupkawan}} nyoë, dari ban dum $2.}}',
+'category-article-count' => '{{PLURAL:$2|Kawan nyoë cit na saboh ôn nyoë.|Kawan nyoë na  {{PLURAL:$1|ôn|$1 ôn }}, dari ban dum $2.}}',
 'listingcontinuesabbrev' => 'samb.',
 
-'about'     => 'Bhah',
-'newwindow' => '(peuhah bak tingkap barô)',
-'cancel'    => 'Peubateuë',
-'qbfind'    => 'Mita',
-'qbedit'    => 'Andam',
-'mytalk'    => 'Peugah haba lôn',
+'about'      => 'Bhah',
+'newwindow'  => '(peuhah bak tingkap barô)',
+'cancel'     => 'Peubateuë',
+'qbfind'     => 'Mita',
+'qbedit'     => 'Andam',
+'mytalk'     => 'Peugah haba lôn',
+'navigation' => 'Navigasi',
 
 'errorpagetitle'   => 'Seunalah',
 'returnto'         => 'Gisa u $1.',
@@ -83,9 +99,11 @@ $messages = array(
 'printableversion' => 'Seunalén citak',
 'permalink'        => 'Hubông teutap',
 'edit'             => 'Andam',
+'create'           => 'Peugöt',
 'editthispage'     => 'Andam ôn nyoë',
 'delete'           => 'Sampôh',
 'protect'          => 'Peulindông',
+'protect_change'   => 'ubah',
 'newpage'          => 'Ôn barô',
 'talkpage'         => 'Peugah haba bhah ôn nyoë',
 'talkpagelinktext' => 'Peugah haba',
@@ -93,8 +111,10 @@ $messages = array(
 'talk'             => 'Peugah haba',
 'views'            => 'Leumah',
 'toolbox'          => 'Plôk alat',
+'otherlanguages'   => 'Bahsa la’én',
 'redirectedfrom'   => '(Geupeupinah nibak $1)',
 'redirectpagesub'  => 'Ôn peupinah',
+'lastmodifiedat'   => 'Ôn nyoë keuneulheuëh geu’ubah bak $2, $1.', # $1 date, $2 time
 'jumpto'           => 'Langsông u:',
 'jumptonavigation' => 'navigasi',
 'jumptosearch'     => 'mita',
@@ -102,6 +122,7 @@ $messages = array(
 # All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
 'aboutsite'            => 'Bhah {{SITENAME}}',
 'aboutpage'            => 'Project:Bhah Ôn',
+'copyright'            => 'Asoë nyang na seusuai ngön $1.',
 'copyrightpage'        => '{{ns:project}}:Hak karang',
 'currentevents'        => 'Peristiwa paléng barô',
 'currentevents-url'    => 'Project:Peristiwa paléng barô',
@@ -117,12 +138,16 @@ $messages = array(
 'privacy'              => 'Jaga rahsia',
 'privacypage'          => 'Project:Jaga rahsia',
 
+'badaccess' => 'Salah hak tamong',
+
 'retrievedfrom'       => 'Meurumpok nibak "$1"',
 'youhavenewmessages'  => 'Droëneuh   na $1 ($2).',
 'newmessageslink'     => 'peusan barô',
 'newmessagesdifflink' => 'neu’ubah keuneulheuëh',
 'editsection'         => 'andam',
 'editold'             => 'andam',
+'editlink'            => 'andam',
+'viewsourcelink'      => 'eu nè',
 'editsectionhint'     => 'Andam bideuëng: $1',
 'toc'                 => 'Asoë',
 'showtoc'             => 'peuleumah',
@@ -130,20 +155,30 @@ $messages = array(
 'site-rss-feed'       => 'Eumpeuën RSS $1',
 'site-atom-feed'      => 'Eumpeuën Atôm $1',
 'page-rss-feed'       => 'Eumpeuën RSS "$1"',
+'page-atom-feed'      => 'Umpeuën Atom "$1"',
+'red-link-title'      => '$1 (ôn goh na)',
 
 # Short words for each namespace, by default used in the namespace tab in monobook
+'nstab-main'     => 'Ôn',
 'nstab-user'     => 'Nyang nguy',
+'nstab-special'  => 'Husôh',
 'nstab-project'  => 'Proyèk ôn',
 'nstab-image'    => 'Beureukah',
 'nstab-template' => 'Templat',
 'nstab-category' => 'Kawan',
 
 # General errors
-'badtitle'       => 'Nan hana sah',
-'badtitletext'   => 'Nan ôn nyang neulakèë hana sah, soh, atawa nan antarabahsa atawa antarawiki nyang salah sambông.',
-'viewsource'     => 'Eu nè',
-'viewsourcefor'  => 'keu $1',
-'viewsourcetext' => 'Droëneuh  jeuët neu’eu',
+'missing-article'    => 'Basis data h’an jeuët jiteumèë naseukah nibak ôn nyang sipatôtjih na, nakeuh "$1" $2.
+
+Nyoë biasajih sabab hubông useuëng u geunantoë away nyang ka teusampôh.
+
+Meunyo kön nyoë sababjih, Droëneuh kadang ka neuteumèë saboh bug lam software. Neutulông peugah bhah nyoë bak salah sidroë [[Special:ListUsers/sysop|Nyang urôh]], ngön neupeugah alamat URL nyang neusaweuë.',
+'missingarticle-rev' => '(revisi#: $1)',
+'badtitle'           => 'Nan hana sah',
+'badtitletext'       => 'Nan ôn nyang neulakèë hana sah, soh, atawa nan antarabahsa atawa antarawiki nyang salah sambông.',
+'viewsource'         => 'Eu nè',
+'viewsourcefor'      => 'keu $1',
+'viewsourcetext'     => 'Droëneuh  jeuët neu’eu',
 
 # Login and logout pages
 'yourname'                => 'Nan nyang nguy:',
@@ -207,17 +242,17 @@ Droëneuh geupeusaran keu neutamong sigra, lheuëh nyan neugantoë lageuëm rahs
 'hr_tip'          => 'Garéh data',
 
 # Edit pages
-'summary'                => 'Reuningkah:',
-'subject'                => 'Bhah/nan:',
-'minoredit'              => 'Nyoë lôn andam bacut',
-'watchthis'              => 'Kalön ôn nyoë',
-'savearticle'            => 'Keubah ôn',
-'preview'                => 'Eu dilèë',
-'showpreview'            => 'Peuleumah hasé',
-'showdiff'               => 'Peuleumah neu’ubah',
-'anoneditwarning'        => 'Droëneuh   hana teudapeuta tamong. Alamat IP Droëneuh   teucatat lam tarèh (riwayat away) ôn nyoë.',
-'summary-preview'        => 'Eu dilèë reuningkah:',
-'blockedtext'            => "<big>'''Nan nyang nguy atawa alamat IP Droëneuh  ka geutheun.'''</big> 
+'summary'                          => 'Reuningkah:',
+'subject'                          => 'Bhah/nan:',
+'minoredit'                        => 'Nyoë lôn andam bacut',
+'watchthis'                        => 'Kalön ôn nyoë',
+'savearticle'                      => 'Keubah ôn',
+'preview'                          => 'Eu dilèë',
+'showpreview'                      => 'Peuleumah hasé',
+'showdiff'                         => 'Peuleumah neu’ubah',
+'anoneditwarning'                  => 'Droëneuh   hana teudapeuta tamong. Alamat IP Droëneuh   teucatat lam tarèh (riwayat away) ôn nyoë.',
+'summary-preview'                  => 'Eu dilèë reuningkah:',
+'blockedtext'                      => "<big>'''Nan nyang nguy atawa alamat IP Droëneuh  ka geutheun.'''</big> 
 
 Geutheun lé $1. Dalèh jih nakeuh ''$2''. 
 
@@ -230,21 +265,25 @@ Droëneuh   jeuët neutanyong bak $1 atawa [[{{MediaWiki:Grouppage-sysop}}|nyang
 Droëneuh   h’an jeuët neunguy alat 'Kirém surat-e nyang nguy nyoë' keucuali ka neupasoë alamat surat-e nyang sah di [[Special:Preferences|Geunalak]] Droëneuh ngön Droëneuh ka geutheun keu nguy nyan.
 
 Alamat IP Droëneuh nakeuh $3, ngön ID neutheun nakeuh $5. Tulông peuseureuta salah saboh atawa ban duwa beurita nyoë bak tiëp teunanyöng nyang neupeugöt.",
-'newarticle'             => '(Barô)',
-'newarticletext'         => "Droëneuh   ka neuseutot u ôn nyang goh na. Keu peugöt ôn nyan, neukeutik asoë ôn di  kutak di yup nyoë (ngiëng [[{{MediaWiki:Helppage}}|ôn bantu]] keu beurita leubèh lanjut). Meunyo Droëneuh  hana neusaja ka trôk keunoë, teugon '''back''' nyang na bak layeuë.",
-'noarticletext'          => 'Hana naseukah jinoë lam ôn nyoë. I Droëneuh   jeuët [[Special:Search/{{PAGENAME}}|mita keu nan ôn nyoë]] bak ôn-ôn la’én atawa [{{fullurl:{{FULLPAGENAME}}|action=edit}} andam ôn nyoë].',
-'previewnote'            => "'''Beuneuingat meunyo nyoë goh lom neukeubah!'''",
-'editing'                => 'Andam $1',
-'editingsection'         => 'Andam $1 (bideuëng)',
-'copyrightwarning'       => "Beuneuingat bahwa ban mandum nyang Droëneuh   tuléh keu {{SITENAME}} geukira geupeuteubiët di yup $2 (ngiëng $1 keu leubèh jeulah). Meunyoë Droëneuh h‘an neutém teunuléh Droëneuh  ji’andam ngön jiba ho ho la’én, bèk neupasoë teunuléh Droëneuh  keunoë.<br />Droëneuh  neumeujanji chit meunyoë teunuléh nyoë nakeuh atra neutuléh keudroë, atawa neucok nibak nè nè atra umôm atawa nè bibeuëh la’én.
+'newarticle'                       => '(Barô)',
+'newarticletext'                   => "Droëneuh   ka neuseutot u ôn nyang goh na. Keu peugöt ôn nyan, neukeutik asoë ôn di  kutak di yup nyoë (ngiëng [[{{MediaWiki:Helppage}}|ôn bantu]] keu beurita leubèh lanjut). Meunyo Droëneuh  hana neusaja ka trôk keunoë, teugon '''back''' nyang na bak layeuë.",
+'noarticletext'                    => 'Hana naseukah jinoë lam ôn nyoë. Ji Droëneuh jeuët [[Special:Search/{{PAGENAME}}|neumita keu nan ôn nyoë]] bak ôn-ôn la’én atawa [{{fullurl:{{FULLPAGENAME}}|action=edit}} andam ôn nyoë].',
+'updated'                          => '(Seubarô)',
+'note'                             => "'''Ceunatat:'''",
+'previewnote'                      => "'''Beuneuingat meunyo nyoë goh lom neukeubah!'''",
+'editing'                          => 'Andam $1',
+'editingsection'                   => 'Andam $1 (bideuëng)',
+'copyrightwarning'                 => "Beuneuingat bahwa ban mandum nyang Droëneuh   tuléh keu {{SITENAME}} geukira geupeuteubiët di yup $2 (ngiëng $1 keu leubèh jeulah). Meunyoë Droëneuh h‘an neutém teunuléh Droëneuh  ji’andam ngön jiba ho ho la’én, bèk neupasoë teunuléh Droëneuh  keunoë.<br />Droëneuh  neumeujanji chit meunyoë teunuléh nyoë nakeuh atra neutuléh keudroë, atawa neucok nibak nè nè atra umôm atawa nè bibeuëh la’én.
 '''BÈK NEUPASOË TEUNULÉH NYANG GEUPEULINDÔNG HAK KARANG NYANG HANA IDIN'''",
-'longpagewarning'        => "'''INGAT: Ôn nyoë panyangjih nakeuh $1 kilobit; ladôm alat rawoh web kadang na masalah bak ji’andam ôn nyang panyangjih 32 kb atawa leubèh. Beu neupeutimang keu neuplah jeuët padum boh beunagi nyang leubèh cut. '''",
-'templatesused'          => 'Templat nyang geunguy bak ôn nyoë:',
-'templatesusedpreview'   => 'Templat nyang geunguy bak eu dilèë nyoë',
-'template-protected'     => '(geulindông)',
-'template-semiprotected' => '(seumi-lindông)',
-'nocreatetext'           => '{{SITENAME}} ka jikot bak peugöt ôn barô. Ji Droëneuh   jeuët neuriwang teuma ngön neu’andam ôn nyang ka na, atawa [[Special:UserLogin|neutamong atawa neudapeuta]].',
-'recreate-deleted-warn'  => "'''Ingat: Droëneuh  teungoh neupeugöt ulang saboh ôn nyang ka tom geusampôh. ''',
+'longpagewarning'                  => "'''INGAT: Ôn nyoë panyangjih nakeuh $1 kilobit; ladôm alat rawoh web kadang na masalah bak ji’andam ôn nyang panyangjih 32 kb atawa leubèh. Beu neupeutimang keu neuplah jeuët padum boh beunagi nyang leubèh cut. '''",
+'templatesused'                    => 'Templat nyang geunguy bak ôn nyoë:',
+'templatesusedpreview'             => 'Templat nyang geunguy bak eu dilèë nyoë',
+'template-protected'               => '(geulindông)',
+'template-semiprotected'           => '(seumi-lindông)',
+'hiddencategories'                 => 'Ôn nyoë nakeuh anggèëta nibak {{PLURAL:$1|1 kawan teusom |$1 kawan teusom}}:',
+'nocreatetext'                     => '{{SITENAME}} ka jikot bak peugöt ôn barô. Ji Droëneuh   jeuët neuriwang teuma ngön neu’andam ôn nyang ka na, atawa [[Special:UserLogin|neutamong atawa neudapeuta]].',
+'permissionserrorstext-withaction' => 'Droëneuh hana hak tamöng keu $2, muroë {{PLURAL:$1|choë|choë}} nyoë:',
+'recreate-deleted-warn'            => "'''Ingat: Droëneuh  teungoh neupeugöt ulang saboh ôn nyang ka tom geusampôh. ''',
 
 Neutimang-timang dilèë peuë ék patôt neupeulanjut atra nyang teungoh neu’andam.
 Nyoë pat nakeuh log seunampôh nibak ôn nyoë:",
@@ -252,6 +291,7 @@ Nyoë pat nakeuh log seunampôh nibak ôn nyoë:",
 # History pages
 'viewpagelogs'           => 'Eu log ôn nyoë',
 'currentrev'             => 'Geunantoë jinoë',
+'currentrev-asof'        => 'Geunantoë paléng barô bak $1',
 'revisionasof'           => 'Gantoë tiëp $1',
 'revision-info'          => 'Geunantoë tiëp $1; $2', # Additionally available: $3: revision id
 'previousrevision'       => '←Geunantoë sigohlomjih',
@@ -269,6 +309,13 @@ Nyoë pat nakeuh log seunampôh nibak ôn nyoë:",
 # Revision feed
 'history-feed-item-nocomment' => '$1 bak $2', # user at time
 
+# Revision deletion
+'rev-delundel'   => 'peuleumah/peusom',
+'revdel-restore' => 'Ubah leumah',
+
+# Merge log
+'revertmerge' => 'Hana  jadèh peugabông',
+
 # Diffs
 'history-title'           => 'Riwayat geunantoë nibak "$1"',
 'difference'              => '(Bida antara geunantoë)',
@@ -278,25 +325,55 @@ Nyoë pat nakeuh log seunampôh nibak ôn nyoë:",
 'diff-multi'              => '({{PLURAL:$1|Sa|$1}} geunantoë antara hana geupeuleumah.)',
 
 # Search results
-'noexactmatch'   => "'''Hana ôn nyang nanjih ''$1''. ''' Droëneuh   jeuët [[:$1|peugèt ôn nyoë]].",
-'prevn'          => '$1 sigohlomjih',
-'nextn'          => '$1 lheuëh nyan',
-'viewprevnext'   => 'Eu ($1)($2)($3)',
-'searchhelp-url' => 'Help:Asoë',
-'powersearch'    => 'Mita lanjut',
+'searchresults'             => 'Hasé mita',
+'searchresults-title'       => 'Hasé mita keu "$1"',
+'searchresulttext'          => 'Keu beurita leubèh le bhah meunita bak {{SITENAME}}, eu [[{{MediaWiki:Helppage}}|ôn beunantu]].',
+'searchsubtitle'            => 'Droëneuh neumita \'\'\'[[:$1]]\'\'\' ([[Special:Prefixindex/$1|ban dum ôn nyang geupuphôn ngön "$1"]]{{int:pipe-separator}}[[Special:WhatLinksHere/$1|bandum ôn nyang teuhubông u "$1"]])',
+'searchsubtitleinvalid'     => "Droëneuh neumita '''$1'''",
+'noexactmatch'              => "'''Hana ôn nyang nanjih ''$1''. ''' Droëneuh   jeuët [[:$1|peugèt ôn nyoë]].",
+'noexactmatch-nocreate'     => "'''Hana ôn ngön nan \"\$1\".'''",
+'notitlematches'            => 'Hana nan ôn nyang pah',
+'notextmatches'             => 'Hana naseukah ôn nyang pah',
+'prevn'                     => '$1 sigohlomjih',
+'nextn'                     => '$1 lheuëh nyan',
+'viewprevnext'              => 'Eu ($1)($2)($3)',
+'searchhelp-url'            => 'Help:Asoë',
+'search-result-size'        => '$1 ({{PLURAL:$2|1 kata|$2 kata}})',
+'search-redirect'           => '(peuninah $1)',
+'search-section'            => '(bagian $1)',
+'search-suggest'            => 'Kadang meukeusud Droëneuh nakeuh: $1',
+'search-interwiki-caption'  => 'Buët la’én',
+'search-interwiki-default'  => 'Hasé $1:',
+'search-interwiki-more'     => '(lom)',
+'search-mwsuggest-enabled'  => 'ngon saran',
+'search-mwsuggest-disabled' => 'hana saran',
+'showingresultstotal'       => "Hasé mita {{PLURAL:$4|'''$1'''|'''$1 - $2'''}} dari '''$3'''",
+'nonefound'                 => "'''Ceunatat''': Cit ladôm ruweuëng nyang seucara baku geupeutamöng lam meunita. Ci neupuphôn leunakèë Droëneuh ngön ''all:'' keu mita ban dum asoë (rôh cit ôn peugah haba, tèmplat, ngön nyang la’én (nnl)), atawa neunguy ruweuëng nan nyang neumeuh’eut sibagoë neu’away.",
+'powersearch'               => 'Mita lanjut',
+'powersearch-legend'        => 'Mita lanjôt',
+'powersearch-ns'            => 'Mita bak ruweuëng nan:',
+'powersearch-redir'         => 'Dapeuta peuninah',
+'powersearch-field'         => 'Mita',
 
 # Preferences page
 'preferences'   => 'Geunalak',
 'mypreferences' => 'Geunalak lôn',
 
+# Groups
+'group-sysop' => 'Nyang urôh',
+
 'grouppage-sysop' => '{{ns:project}}:Nyang urôh',
 
 # User rights log
 'rightslog' => 'Log neu’ubah hak peuhah',
 
+# Associated actions - in the sentence "You do not have permission to X"
+'action-edit' => 'andam ôn nyoë',
+
 # Recent changes
 'nchanges'                       => '$1 {{PLURAL:$1|neu’ubah|neu’ubah}}',
 'recentchanges'                  => 'Neu’ubah paléng barô',
+'recentchanges-legend'           => 'Peuniléh neu’ubah paléng barô',
 'recentchanges-feed-description' => 'Peutumèë neu’ubah paléng barô lam wiki bak eumpeuën nyoë.',
 'rcnote'                         => "Di yup nyoë nakeuh {{PLURAL:$1|nakeuh '''1''' neu’ubah paléng barô |nakeuh '''$1''' neu’ubah paléng barô}} lam {{PLURAL:$2|'''1''' uroë|'''$2''' uroë}} nyoë, trôk ‘an $5, $4.",
 'rcnotefrom'                     => 'Di yup nyoë nakeuh neu’ubah yôh <strong>$2</strong> (geupeuleumah trôh ‘an <strong>$1</strong> neu’ubah).',
@@ -315,12 +392,16 @@ Nyoë pat nakeuh log seunampôh nibak ôn nyoë:",
 'minoreditletter'                => 'b',
 'newpageletter'                  => 'B',
 'boteditletter'                  => 'b',
+'rc-enhanced-expand'             => 'Peuleumah reuninci (peureulèë JavaScript)',
+'rc-enhanced-hide'               => 'Peusom reuninci',
 
 # Recent changes linked
 'recentchangeslinked'          => 'Seundi meuhubông',
 'recentchangeslinked-title'    => 'Neu’ubah nyang meuhubông ngön $1',
 'recentchangeslinked-noresult' => 'Hana neu’ubah bak ôn-ôn meuhubông silawét masa nyang ka geupeuteuntèë.',
 'recentchangeslinked-summary'  => "Ôn husôh nyoë geupeuleumah dapeuta neu’ubah keuneulheuëh bak ôn ôn meuhubông. Ôn nyang neukalön geubri tanda ngön '''citak teubay'''.",
+'recentchangeslinked-page'     => 'Nan ôn:',
+'recentchangeslinked-to'       => 'Peuleumah neu’ubah nibak ôn-ôn nyang meusambông ngön ôn nyang geubri',
 
 # Upload
 'upload'        => 'Peutamong',
@@ -336,14 +417,16 @@ Nyoë pat nakeuh log seunampôh nibak ôn nyoë:",
 'filehist-help'             => 'Teugon bak tanggay/watèë keu eu beureukah nyoë ‘oh watèë nyan.',
 'filehist-current'          => 'jinoë hat',
 'filehist-datetime'         => 'Tanggay/Watèë',
+'filehist-thumb'            => 'Beuntuk ubeut',
+'filehist-thumbtext'        => 'Beuntuk ubeut keu seunalén tiëp $1',
 'filehist-user'             => 'Nyang nguy',
 'filehist-dimensions'       => 'Dimènsi',
 'filehist-filesize'         => 'Rayek beureukah',
 'filehist-comment'          => 'Tapeusé',
-'imagelinks'                => 'Hubông',
+'imagelinks'                => 'Hubông beureukah',
 'linkstoimage'              => 'Ôn di yup nyoë na {{PLURAL:$1|hubông|$1 hubông}} u beureukah nyoë:',
 'nolinkstoimage'            => 'Hana ôn nyang na hubông u beureukah nyoë.',
-'sharedupload'              => 'Beureukah nyoë nakeuh teunamong sama-sama nyang mungkén geunguy lé reunancang la’én.',
+'sharedupload'              => 'Beureukah nyoë dari $1 ngön kadang geunguy lé buët-buët la’én.', # $1 is the repo name, $2 is shareduploadwiki(-desc)
 'noimage'                   => 'Hana beureukah ngön nan nyan, Droëneuh jeuët $1.',
 'noimage-linktext'          => 'peutamong beureukah',
 'uploadnewversion-linktext' => 'Peulöt seunalén nyang leubèh barô nibak beureukah nyoë.',
@@ -395,7 +478,7 @@ Nyoë pat nakeuh log seunampôh nibak ôn nyoë:",
 'mostcategories'          => 'Teunuléh ngön kawan paléng le',
 'mostimages'              => 'Beureukah nyang paléng kayém geunguy',
 'mostrevisions'           => 'Teunuléh ngön neu’ubah paléng le',
-'prefixindex'             => 'Dapeuta ôn ngön away harah',
+'prefixindex'             => 'Ban dum ôn ngön neuaway',
 'shortpages'              => 'Ôn paneuk',
 'longpages'               => 'Ôn panyang',
 'deadendpages'            => 'Ôn buntu',
@@ -409,7 +492,9 @@ Nyoë pat nakeuh log seunampôh nibak ôn nyoë:",
 'pager-older-n'           => '{{PLURAL:$1|1 leubèh trép|$1 leubèh trép}}',
 
 # Book sources
-'booksources' => 'Nè kitab',
+'booksources'               => 'Nè kitab',
+'booksources-search-legend' => 'Mita bak sumber buku',
+'booksources-go'            => 'Mita',
 
 # Special:Log
 'specialloguserlabel'  => 'Nyang nguy:',
@@ -423,6 +508,7 @@ Nyoë pat nakeuh log seunampôh nibak ôn nyoë:",
 'nextpage'       => 'Ôn lheuëh nyan ($1)',
 'prevpage'       => 'Ôn sigohlomjih ($1)',
 'allpagesfrom'   => 'Peuleumah ôn peuphôn nibak:',
+'allpagesto'     => 'Peuleumah ôn geupeuakhé bak:',
 'allarticles'    => 'Dapeuta teunuléh',
 'allpagessubmit' => 'Mita',
 'allpagesprefix' => 'Peuleumah ôn ngön harah phôn:',
@@ -430,6 +516,16 @@ Nyoë pat nakeuh log seunampôh nibak ôn nyoë:",
 # Special:Categories
 'categories' => 'Dapeuta kawan',
 
+# Special:LinkSearch
+'linksearch' => 'Hubông luwa',
+
+# Special:Log/newusers
+'newuserlogpage'          => 'nyang nguy barô',
+'newuserlog-create-entry' => 'dapeuta  jeuët anggèëta',
+
+# Special:ListGroupRights
+'listgrouprights-members' => '(dapeuta anggèëta)',
+
 # E-mail user
 'emailuser' => 'Surat-e nyang nguy',
 
@@ -446,6 +542,7 @@ Nyoë pat nakeuh log seunampôh nibak ôn nyoë:",
 'unwatch'           => 'Bateuë kalön',
 'watchlist-details' => '{{PLURAL:$1|$1 ôn|$1 ôn}} geukalön, hana kira ôn peugah haba.',
 'wlshowlast'        => 'Peuleumah $1 jeum $2 uroë $3 keuneulheuëh',
+'watchlist-options' => 'Peuniléh dapeuta kalön',
 
 # Displayed when you click the "watch" button and it is in the process of watching
 'watching'   => 'Kalön...',
@@ -468,6 +565,8 @@ Nyoë pat nakeuh log seunampôh nibak ôn nyoë:",
 
 # Protect
 'protectlogpage'              => 'Log lindông',
+'protectedarticle'            => 'peulindông "[[$1]]"',
+'modifiedarticleprotection'   => 'Ubah tingkat lindông "[[$1]]"',
 'prot_1movedto2'              => 'peupinah [[$1]] u [[$2]]',
 'protectcomment'              => 'Bri peunapat:',
 'protectexpiry'               => 'Maté tanggay:',
@@ -478,9 +577,9 @@ Nyoë pat nakeuh log seunampôh nibak ôn nyoë:",
 'protect-locked-access'       => "Nan dapeuta Droëneuh hana hak keu jak gantoë tingkat lindông ôn. Nyoë pat nakeuh konfigurasi atra jinoë keu ôn '''$1''':",
 'protect-cascadeon'           => 'Ôn nyoë teungöh geulindông kareuna geupeuseureuta lam {{PLURAL:$1|ôn|ôn-ôn}} nyoë nyang ka geulindông ngön peuniléh lindông meuturôt geupeuudép.
 Droëneuh jeuët neugantoë tingkat lindông keu ôn nyoë, tapi nyan hana peungarôh keu lindông meuturôt.',
-'protect-default'             => '(baku)',
+'protect-default'             => 'Peuidin ban dum nyang nguy',
 'protect-fallback'            => 'Peureulèë hak peuhah "$1"',
-'protect-level-autoconfirmed' => 'Nyang nguy nyang teudapeuta mantöng',
+'protect-level-autoconfirmed' => 'Theun nyang nguy barô ngön hana teudapeuta',
 'protect-level-sysop'         => 'Nyang urôh mantöng',
 'protect-summary-cascade'     => 'riti',
 'protect-expiring'            => 'maté tanggay $1 (UTC)',
@@ -491,7 +590,9 @@ Droëneuh jeuët neugantoë tingkat lindông keu ôn nyoë, tapi nyan hana peung
 'restriction-level'           => 'Tingkat:',
 
 # Undelete
-'undeletebtn' => 'Peuriwang!',
+'undeletebtn'      => 'Peuriwang!',
+'undeletelink'     => 'eu/peuriwang',
+'undeletedarticle' => '"$1" ka geupeuriwang',
 
 # Namespace form on various pages
 'namespace'      => 'Ruweuëng nan:',
@@ -499,39 +600,50 @@ Droëneuh jeuët neugantoë tingkat lindông keu ôn nyoë, tapi nyan hana peung
 'blanknamespace' => '(Utama)',
 
 # Contributions
-'contributions' => 'Nyang ka jituléh lé nyang nguy',
-'mycontris'     => 'Nyang lôn peugèt',
-'contribsub2'   => 'Keu $1 ($2)',
-'uctop'         => '(ateuëh)',
-'month'         => 'Yôh buleuën (ngön yôh goh lom nyan)',
-'year'          => 'Yôh thôn (ngön yôh goh lom nyan)',
+'contributions'       => 'Nyang ka jituléh lé nyang nguy',
+'contributions-title' => 'Peuneugèt nyang nguy keu $1',
+'mycontris'           => 'Nyang lôn peugèt',
+'contribsub2'         => 'Keu $1 ($2)',
+'uctop'               => '(ateuëh)',
+'month'               => 'Yôh buleuën (ngön yôh goh lom nyan)',
+'year'                => 'Yôh thôn (ngön yôh goh lom nyan)',
 
 'sp-contributions-newbies'     => 'Keu ureuëng-ureuëng nyang ban nguy mantöng',
 'sp-contributions-newbies-sub' => 'Keu nyang nguy barô',
 'sp-contributions-blocklog'    => 'Log peutheun',
 'sp-contributions-search'      => 'Mita soë nyang tuléh',
 'sp-contributions-username'    => 'Alamat IP atawa nan nyang nguy:',
+'sp-contributions-submit'      => 'Mita',
 
 # What links here
-'whatlinkshere'       => 'Hubông balék',
-'whatlinkshere-title' => 'Ôn nyang na hubông u $1',
-'linkshere'           => "Ôn-ôn nyoë meuhubông u '''[[:$1]]''':",
-'nolinkshere'         => "Hana ôn nyang teuhubông u '''[[:$1]]'''.",
-'isredirect'          => 'ôn peupinah',
-'istemplate'          => 'deungön templat',
-'whatlinkshere-prev'  => '$1 {{PLURAL:$1|sigohlomjih|sigohlomjih}}',
-'whatlinkshere-next'  => '$1 {{PLURAL:$1|lheuëh nyan|lheuëh nyan}}',
-'whatlinkshere-links' => '← hubông',
+'whatlinkshere'            => 'Hubông balék',
+'whatlinkshere-title'      => 'Ôn nyang na hubông u $1',
+'whatlinkshere-page'       => 'Ôn:',
+'linkshere'                => "Ôn-ôn nyoë meuhubông u '''[[:$1]]''':",
+'nolinkshere'              => "Hana ôn nyang teuhubông u '''[[:$1]]'''.",
+'isredirect'               => 'ôn peupinah',
+'istemplate'               => 'deungön templat',
+'isimage'                  => 'hubông beureukah',
+'whatlinkshere-prev'       => '$1 {{PLURAL:$1|sigohlomjih|sigohlomjih}}',
+'whatlinkshere-next'       => '$1 {{PLURAL:$1|lheuëh nyan|lheuëh nyan}}',
+'whatlinkshere-links'      => '← hubông',
+'whatlinkshere-hideredirs' => '$1 peuninah',
+'whatlinkshere-hidetrans'  => '$1 transklusi',
+'whatlinkshere-hidelinks'  => '$1 hubông',
+'whatlinkshere-filters'    => 'Saréng',
 
 # Block/unblock
-'blockip'       => 'Theun nyang nguy',
-'ipboptions'    => '2 jeum:2 hours,1 uroë:1 day,3 uroë:3 days,1 minggu:1 week,2 minggu:2 weeks,1 buleuën:1 month,3 buleuën:3 months,6 buleuën:6 months,1 thôn:1 year,sabé:infinite', # display1:time1,display2:time2,...
-'ipblocklist'   => 'Dapeuta neutheun',
-'blocklink'     => 'theun',
-'unblocklink'   => 'peugadöh theun',
-'contribslink'  => 'nyang geupeugèt',
-'blocklogpage'  => 'Log peutheun',
-'blocklogentry' => 'theun [[$1]] ngön watèë maté tanggay $2 $3',
+'blockip'                  => 'Theun nyang nguy',
+'ipboptions'               => '2 jeum:2 hours,1 uroë:1 day,3 uroë:3 days,1 minggu:1 week,2 minggu:2 weeks,1 buleuën:1 month,3 buleuën:3 months,6 buleuën:6 months,1 thôn:1 year,sabé:infinite', # display1:time1,display2:time2,...
+'ipblocklist'              => 'Dapeuta neutheun',
+'blocklink'                => 'theun',
+'unblocklink'              => 'peugadöh theun',
+'change-blocklink'         => 'ubah theun',
+'contribslink'             => 'nyang geupeugèt',
+'blocklogpage'             => 'Log peutheun',
+'blocklogentry'            => 'theun [[$1]] ngön watèë maté tanggay $2 $3',
+'unblocklogentry'          => 'peugadöh theun "$1"',
+'block-log-flags-nocreate' => 'pumeugöt nan geupumaté',
 
 # Move page
 'movepagetext'     => "Formulir di yup nyoë geunguy keu jak ubah nan saboh ôn ngön jak peupinah ban dum data riwayat u nan barô. Nan nyang trép euntreuk jeuët keu ôn peupinah u nan nyang barô. Hubông u nan trép hana meu’ubah. Neupeupaseuti keu neupréksa peuninah ôn nyang reulöh atawa meuganda lheuëh neupinah. Droëneuh nyang mat tanggông jaweuëb keu neupeupaseuti meunyo hubông laju teusambông u ôn nyang patôt.
@@ -556,6 +668,7 @@ Lam masalah nyoë, meunyo neuhawa, Droëneuh jeuët neupeupinah atawa neupeugab
 'movedto'          => 'geupeupinah u',
 'movetalk'         => 'Peupinah ôn peugah haba nyang na hubôngan.',
 '1movedto2'        => 'peupinah [[$1]] u [[$2]]',
+'1movedto2_redir'  => 'pupinah [[$1]] u [[$2]] röt peuninah',
 'movelogpage'      => 'Log pinah',
 'movereason'       => 'Choë:',
 'revertmove'       => 'peuriwang',
@@ -574,24 +687,27 @@ Lam masalah nyoë, meunyo neuhawa, Droëneuh jeuët neupeupinah atawa neupeugab
 'importlogpage' => 'Log impor',
 
 # Tooltip help for the actions
-'tooltip-pt-userpage'             => 'Ôn lôn',
-'tooltip-pt-mytalk'               => 'Ôn peugah haba lôn',
+'tooltip-pt-userpage'             => 'Ôn nguy Droëneuh',
+'tooltip-pt-mytalk'               => 'Ôn peugah haba Droëneuh',
 'tooltip-pt-preferences'          => 'Geunalak lôn',
 'tooltip-pt-watchlist'            => 'Dapeuta ôn nyang lôn kalön',
-'tooltip-pt-mycontris'            => 'Dapeuta nyang ka lôn peugèt',
+'tooltip-pt-mycontris'            => 'Dapeuta peuneugèt Droëneuh',
 'tooltip-pt-login'                => 'Droën geupeusaran keu tamong log, bahpih nyan hana geupeuwajéb.',
 'tooltip-pt-logout'               => 'Teubiët',
 'tooltip-ca-talk'                 => 'Peugah haba ôn asoë',
 'tooltip-ca-edit'                 => 'Andam ôn nyoë. Nguy tumbôy euë dilèë yôh goh lom keumeubah.',
-'tooltip-ca-addsection'           => 'Peutamah tapeusé u ôn peugah haba nyoë.',
+'tooltip-ca-addsection'           => 'Puphôn beunagi barô',
 'tooltip-ca-viewsource'           => 'Ôn nyoë geupeulindông. 
 Droëneuh cuman jeuët neu’eu nèjih.',
+'tooltip-ca-history'              => 'Seunalén-seunalén sigohlomjih nibak ôn nyoë',
 'tooltip-ca-protect'              => 'Peulindông ôn nyoë',
 'tooltip-ca-delete'               => 'Sampôh ôn nyoë',
 'tooltip-ca-move'                 => 'Peupinah ôn nyoë',
 'tooltip-ca-watch'                => 'Peutamah ôn nyoë u dapeuta kalön Droëneuh',
 'tooltip-ca-unwatch'              => 'Sampôh ôn nyoë nibak dapeuta keunalön Droëneuh',
 'tooltip-search'                  => 'Mita lam {{SITENAME}} nyoë',
+'tooltip-search-go'               => 'Mita saboh ôn ngon nan nyang peureuséh lagèë nyoë meunyo na',
+'tooltip-search-fulltext'         => 'Mita ôn nyang na asoë lagèë nyoë',
 'tooltip-n-mainpage'              => 'Jak u Ôn Keuë',
 'tooltip-n-portal'                => 'Bhah buët, peuë nyang jeuët neupeulaku, pat tamita sipeuë hay',
 'tooltip-n-currentevents'         => 'Mita beurita nyang paléng barô',
@@ -599,11 +715,19 @@ Droëneuh cuman jeuët neu’eu nèjih.',
 'tooltip-n-randompage'            => 'Peuleumah beurangkari ôn',
 'tooltip-n-help'                  => 'Bak mita bantu.',
 'tooltip-t-whatlinkshere'         => 'Dapeuta mandum ôn wiki nyang na hubông u ôn nyoë',
+'tooltip-t-recentchangeslinked'   => 'Neu’ubah paléng barô ôn-ôn nyang na hubông u ôn nyoë',
+'tooltip-feed-rss'                => 'Umpeuën RSS keu ôn nyoë',
+'tooltip-feed-atom'               => 'Umpeuën Atom keu ôn nyoë',
 'tooltip-t-contributions'         => 'Eu dapeuta nyang ka geutuléh lé nyang nguy nyoë',
 'tooltip-t-emailuser'             => 'Kirém surat-e u nyang nguy nyoë',
 'tooltip-t-upload'                => 'Peutamong gamba atawa beureukah alat',
 'tooltip-t-specialpages'          => 'Dapeuta mandum ôn husôh',
+'tooltip-t-print'                 => 'Seunalén citak ôn nyoë',
+'tooltip-t-permalink'             => '
+Hubông teutap keu revisi ôn nyoë',
+'tooltip-ca-nstab-main'           => 'Eu ôn asoë',
 'tooltip-ca-nstab-user'           => 'Eu ôn nyang nguy',
+'tooltip-ca-nstab-special'        => 'Nyoë nakeuh ôn husôh nyang h’an jeuët geu’andam.',
 'tooltip-ca-nstab-project'        => 'Eu ôn buët',
 'tooltip-ca-nstab-image'          => 'Eu ôn beureukah',
 'tooltip-ca-nstab-template'       => 'Eu templat',
@@ -615,6 +739,8 @@ Droëneuh cuman jeuët neu’eu nèjih.',
 'tooltip-diff'                    => 'Peuleumah neu’ubah nyang ka Droëneuh peugèt',
 'tooltip-compareselectedversions' => 'Ngiëng bida antara duwa curak ôn nyang jipilèh.',
 'tooltip-watch'                   => 'Peutamah ôn nyoë u dapeuta keunalön Droëneuh',
+'tooltip-rollback'                => 'Peuriwang neu’andam-neu’andam bak ôn nyoë u nyang tuléh keuneulheuëh lam sigo teugön',
+'tooltip-undo'                    => 'Peuriwang geunantoë nyoë ngön peuhah plôk neu’andam ngön cara eu dilèë. Choë jeuët geupeutamah bak plôk reuningkah.',
 
 # Browsing diffs
 'previousdiff' => '← Bida away',
@@ -647,6 +773,7 @@ Hubông-hubông lheuëh nyan bak baréh nyang saban geukira sibagoë keucuali, n
 * datetimeoriginal
 * exposuretime
 * fnumber
+* isospeedratings
 * focallength', # Do not translate list items
 
 # External editor support
