@@ -1,5 +1,8 @@
 <?php
 /** Fijian (Na Vosa Vakaviti)
+ *
+ * See MessagesQqq.php for message documentation incl. usage of parameters
+ * To improve a translation please visit http://translatewiki.net
  *
  * @ingroup Language
  * @file
@@ -110,7 +113,7 @@ $messages = array(
 'email'              => 'I vola livaliva',
 
 # Edit pages
-'summary'      => 'Kena i Soqoni',
+'summary'      => 'Kena i Soqoni:',
 'watchthis'    => 'Vakaraica toka na tabana oqo',
 'savearticle'  => 'Vakabula na tabana oqo',
 'showpreview'  => 'Vakaraitaka na kenai yaloyalo',
@@ -189,7 +192,7 @@ $messages = array(
 'tooltip-search'         => 'Vaqaqara {{SITENAME}}',
 'tooltip-p-logo'         => 'Tabana levu',
 
-# Special:NewImages
+# Special:NewFiles
 'ilsubmit' => 'Vaqaqara',
 
 # Multipage image navigation
