@@ -1,5 +1,8 @@
 <?php
 /** Mingrelian (მარგალური)
+ *
+ * See MessagesQqq.php for message documentation incl. usage of parameters
+ * To improve a translation please visit http://translatewiki.net
  *
  * @ingroup Language
  * @file
@@ -96,7 +99,7 @@ $messages = array(
 'mypage'         => 'ჩქიმ ხასილა',
 'mytalk'         => 'ჩქიმ სხუნუა',
 'navigation'     => 'ნავიგაცია',
-'and'            => 'დო',
+'and'            => '&#32;დო',
 
 'errorpagetitle'   => 'შეცთომა',
 'returnto'         => 'დირთი $1-შა',
@@ -139,7 +142,7 @@ $messages = array(
 'currentevents'        => 'მიმალ მოლინეფ',
 'currentevents-url'    => 'Project:მიმალ მოლინეფ',
 'disclaimers'          => 'გამამინჯალაშ მონწყუმა',
-'disclaimerpage'       => 'Project::პასუხისმგებლობაშ ვარება',
+'disclaimerpage'       => 'Project:პასუხისმგებლობაშ ვარება',
 'edithelp'             => 'მოხვარა',
 'edithelppage'         => 'Help:ტექსტიშ რედაქტირაფა (იოლი)',
 'helppage'             => 'Help:მოხვარა',
@@ -229,8 +232,8 @@ $messages = array(
 'hr_tip'          => 'ჰორიზონტალურ ხაზ (ნუ გამოიყენებთ ხშირას)',
 
 # Edit pages
-'summary'                => 'რეზიუმე',
-'subject'                => 'თემა/სახელ',
+'summary'                => 'რეზიუმე:',
+'subject'                => 'თემა/სახელ:',
 'minoredit'              => 'ჭიჭე რედაქტირაფა',
 'watchthis'              => 'თე ხასილაშ კონტროლ',
 'savearticle'            => 'ჩუალა',
@@ -238,7 +241,7 @@ $messages = array(
 'showpreview'            => 'ოწოხიან გინოჯინა',
 'showdiff'               => 'თირაფეფიშ ძირაფა',
 'anoneditwarning'        => "'''გათხილება:''' თქვა ვარეთ რეგისტრირებულ. თქვან IP მისამართ დინოჭარილ იჸიი თე ხასილაშ რედაქტირაფაშ ისტორიას.",
-'summary-preview'        => 'რეზიუმეშ ოწოხიან გინოჯინა',
+'summary-preview'        => 'რეზიუმეშ ოწოხიან გინოჯინა:',
 'blockedtext'            => "<big>'''თქვან მახვარებუშ ჯოხო ვარა IP მიოწურაფუქ ბლოკირქ იჸუ. '''</big> 
 
 ბლოკირაფა ღოლუ $-ქ. 
@@ -258,13 +261,13 @@ $messages = array(
 (ძირ.[[{{MediaWiki:Helppage}}|მოხვარაშ ხასილა]] გეძინელ ინფორმაციაშო).
 თე ხასილას ჩილათირო მოხვადით და, დირთით უკახალე თქვან ბრაუზერიშ ხენწყუალათ.',
 'noarticletext'          => 'ასე თე ხასილას ტექსტ ვარე, [[Special:Search/{{PAGENAME}}|მიგორეთ თე ხასილაშ სახელ]] შხვა ხასილებს ვარა [{{fullurl:{{FULLPAGENAME}}|action=edit}} დოჭარით თენა ხასილა].',
-'previewnote'            => '<strong> ენა ხვალე ნიმუშიე; თირაფეფ დიო ვა ჩუალე!</strong>',
+'previewnote'            => "''' ენა ხვალე ნიმუშიე; თირაფეფ დიო ვა ჩუალე!'''",
 'editing'                => 'რედაქტირაფა - $1',
 'editingsection'         => 'რედაქტირაფა - $1 (სექცია)',
 'yourtext'               => 'თქვან ტექსტ',
-'copyrightwarning'       => 'თოლჸუჯი ქიმეჩით: ნამდგა ვა რდას თიამიშნაღელი ხასილას {{SITENAME}} $2 ლიცენზიას ათოჸუნს(ძირით $1 დეტალეფშოთ). ვა გოკონა თქვან ნახანდიშ დუდშულო გოფაჩუა დო თიშ უდუნდებელ რედაქტირაფა და, თიწკუმა ვა მიშეჸონათ თინა თაქ.<br />
+'copyrightwarning'       => "თოლჸუჯი ქიმეჩით: ნამდგა ვა რდას თიამიშნაღელი ხასილას {{SITENAME}} $2 ლიცენზიას ათოჸუნს(ძირით $1 დეტალეფშოთ). ვა გოკონა თქვან ნახანდიშ დუდშულო გოფაჩუა დო თიშ უდუნდებელ რედაქტირაფა და, თიწკუმა ვა მიშეჸონათ თინა თაქ.<br />
 თქვა ხოლო პიჯალას დუთმოდვანთ, ნამდა თენა თქვან ნაჭარა რე, ვარა გინოღალირ რე ოირკოჩე დომენშე, დო ვარა თიშ მანგურ დუდშულ წყუშე. 
-<strong> ვა მიშეღათ ოავტორე უფლებებით თხილერ ნახანდი ავტორიშ ქოჸიაშ უმშო!</strong>',
+''' ვა მიშეღათ ოავტორე უფლებებით თხილერ ნახანდი ავტორიშ ქოჸიაშ უმშო!'''",
 'templatesused'          => 'თე ხასილას გიმორინაფილ თარგეფ:',
 'templatesusedpreview'   => 'თარგეფ, ნამუთ ოწოხიან გინოჯინაშ ხასილას რე გიმორინაფილ',
 'template-protected'     => '(თხილერი)',
@@ -279,7 +282,7 @@ $messages = array(
 'viewpagelogs'        => 'თე ხასილაშა სარეგისტრაციე ჟურნალეფიშ ძირაფა',
 'currentrev'          => 'მიმალ გიშანწყუალა',
 'revisionasof'        => '$1-იშ ვერსია',
-'revision-info'       => '$1-იშ ვერსია, $2-იშ მიშაღალირ',
+'revision-info'       => '$1-იშ ვერსია, $2-იშ მიშაღალირ', # Additionally available: $3: revision id
 'previousrevision'    => '←ჯვეშ ვერსია',
 'nextrevision'        => 'უკულ ვერსია→',
 'currentrevisionlink' => 'მიმალ ვერსია',
@@ -308,11 +311,12 @@ $messages = array(
 'editundo'                => 'გაუქვება',
 
 # Search results
-'noexactmatch' => "'''ხასილა თე სახელით \"\$1\" ვაარსეენს.''' თქვა შეილებნა [[:\$1|თე გვერდიშ ღოლამა]].",
-'prevn'        => 'წოხლენ $1',
-'nextn'        => 'უკულ $1',
-'viewprevnext' => 'ქოძირ  ($1) ($2) ($3).',
-'powersearch'  => 'გორუა',
+'noexactmatch'   => "'''ხასილა თე სახელით \"\$1\" ვაარსეენს.''' თქვა შეილებნა [[:\$1|თე გვერდიშ ღოლამა]].",
+'prevn'          => 'წოხლენ $1',
+'nextn'          => 'უკულ $1',
+'viewprevnext'   => 'ქოძირ  ($1) ($2) ($3).',
+'searchhelp-url' => 'Help:მოხვარა',
+'powersearch'    => 'გორუა',
 
 # Preferences page
 'preferences'   => 'კონფიგურაცია',
@@ -356,11 +360,11 @@ $messages = array(
 'uploadlogpage' => 'გიმოხარგუაშ რეგისტრაცია',
 'uploadedimage' => 'გეთებაა "[[$1]]"',
 
-# Special:ImageList
-'imagelist'      => 'სურათეფიშ ერკებულ',
-'imagelist_name' => 'სახელ',
+# Special:ListFiles
+'listfiles'      => 'სურათეფიშ ერკებულ',
+'listfiles_name' => 'სახელ',
 
-# Image description page
+# File description page
 'filehist'            => 'ფაილიშ ისტორია',
 'filehist-help'       => 'ქოგეუნჭირით ბორჯის, ნამდა ქოძირათ ფაილი თეშ, მუჭოთ თინა თიწკუმა კილეძირედუ.',
 'filehist-current'    => 'მიმალ',
@@ -372,7 +376,7 @@ $messages = array(
 'imagelinks'          => 'რსხილეფ',
 'linkstoimage'        => 'გეჸვენჯი {{PLURAL:$1|ხასილა|ხასილეფ}} მორცხუ თე ფაილს',
 'nolinkstoimage'      => 'ვა რე თე ფაილწკუმა მერსხილ ხასილეფ.',
-'sharedupload'        => 'თენა ფაილ გეთებულ რე საართო სარგებლობაშოთ დო შილებე თიში გიმორინაფა შხვა პროექტეფს.',
+'sharedupload'        => 'თენა ფაილ გეთებულ რე საართო სარგებლობაშოთ დო შილებე თიში გიმორინაფა შხვა პროექტეფს.', # $1 is the repo name, $2 is shareduploadwiki(-desc)
 'noimage'             => 'ფაილ თე სახელით ვაარსეენც, თქვან შეგილებუნთ $1.',
 
 # MIME search
@@ -429,32 +433,34 @@ $messages = array(
 'emailuser' => 'მიდუჯღონით ელ.ფოშტა ათე მახვარებუს',
 
 # Watchlist
-'watchlist'            => 'ჩქიმ კონტროლიშ ხასილეფ',
-'mywatchlist'          => 'ჩქიმ კონტროლიშ ერკებულ',
-'watchlistfor'         => "('''$1'''-შენი)",
-'removedwatchtext'     => 'ასე გვერდ "[[:$1]]" ვარე თქვან კონტროლიშ გვერდეფს.',
-'watch'                => 'კონტროლ',
-'watchthispage'        => 'თე ხასილაშ კონტროლ',
-'unwatch'              => 'კონტროლიშ გაუქვება',
-'watchlist-details'    => '$1 ხასილას კილმაჯინეთ სხუნუაშ ხასილაშ უკოროცხუო.',
-'wlshowlast'           => 'ძირაფა ბოლო $1 საათიშ $2 დღაშ $3',
-'watchlist-hide-bots'  => 'რობოტიშ თირუეფიშ ფულუა',
-'watchlist-hide-own'   => 'ჩქიმ რედაქტირებაშ ფულუა',
-'watchlist-hide-minor' => 'ჭიჭე რედაქტირებებაშ ფულუა',
+'watchlist'         => 'ჩქიმ კონტროლიშ ხასილეფ',
+'mywatchlist'       => 'ჩქიმ კონტროლიშ ერკებულ',
+'watchlistfor'      => "('''$1'''-შენი)",
+'removedwatchtext'  => 'ასე გვერდ "[[:$1]]" ვარე თქვან კონტროლიშ გვერდეფს.',
+'watch'             => 'კონტროლ',
+'watchthispage'     => 'თე ხასილაშ კონტროლ',
+'unwatch'           => 'კონტროლიშ გაუქვება',
+'watchlist-details' => '$1 ხასილას კილმაჯინეთ სხუნუაშ ხასილაშ უკოროცხუო.',
+'wlshowlast'        => 'ძირაფა ბოლო $1 საათიშ $2 დღაშ $3',
 
 # Displayed when you click the "watch" button and it is in the process of watching
 'watching'   => 'კონტროლირაფონი...',
 'unwatching' => 'ვაკონტროლირაფონი...',
 
-# Delete/protect/revert
-'deletepage'                  => 'ხასილაშ შალუა',
-'actioncomplete'              => 'მოქმედალა რსულებულ რე',
-'deletedarticle'              => 'წაშალულ რე "[[$1]]"',
-'dellogpage'                  => 'ლასირეფიშ ერკებულ',
-'deleteotherreason'           => 'შხვა/დამატებით ბაძაძი:',
-'deletereasonotherlist'       => 'შხვა ბაძაძი',
-'rollbacklink'                => 'გაუქვება',
+# Delete
+'deletepage'            => 'ხასილაშ შალუა',
+'actioncomplete'        => 'მოქმედალა რსულებულ რე',
+'deletedarticle'        => 'წაშალულ რე "[[$1]]"',
+'dellogpage'            => 'ლასირეფიშ ერკებულ',
+'deleteotherreason'     => 'შხვა/დამატებით ბაძაძი:',
+'deletereasonotherlist' => 'შხვა ბაძაძი',
+
+# Rollback
+'rollbacklink' => 'გაუქვება',
+
+# Protect
 'protectlogpage'              => 'თხილუაშ ისტორია',
+'prot_1movedto2'              => '[[$1]] გინოღალირიე ხასილაშა [[$2]]',
 'protectcomment'              => 'კომენტარ:',
 'protectexpiry'               => 'ვადა',
 'protect-unchain'             => 'გინოღალას ალობას ბლოკიშ მონწყუმა',
@@ -463,6 +469,7 @@ $messages = array(
 'protect-level-autoconfirmed' => 'ვარეგისტრირებულ მახვარებელეფიშ დაბლოკვა',
 'protect-level-sysop'         => 'ხვალე ადმინისტრატორეფ',
 'protect-summary-cascade'     => 'იერარქიულ',
+'protect-expiry-options'      => '2 საათი:2 hours,1 დღა:1 დღა,3 დღა:3 დღალეფ,1 მარა:1 week,2 მარა:2 weeks,1 თუთა:1 month,3 თუთა:3 months,6 თუთა:6 months,1 წანა:1 year,განუსაზღვრელი ვადით:infinite', # display1:time1,display2:time2,...
 'restriction-type'            => 'ულაფა',
 
 # Undelete
@@ -489,7 +496,6 @@ $messages = array(
 'whatlinkshere'       => 'სო რე თენა ხასილა წურაფილ',
 'whatlinkshere-title' => 'ხასილეფ, სოდეთ რენა რსხილეფ $1-ს',
 'whatlinkshere-page'  => 'გვერდ:',
-'linklistsub'         => '(რსხილეფ)',
 'linkshere'           => "გეჸვენჯ ხასილეფს ოხოლუ რსხილეფ '''[[:$1]]'''-შენ",
 'nolinkshere'         => "'''[[:$1]]''', თე ხასილას ვარე რსხილ.",
 'isredirect'          => 'გინოწურაფაშ ხასილა',
@@ -590,7 +596,7 @@ $messages = array(
 'show-big-image'       => 'რსული გარჩევადობა',
 'show-big-image-thumb' => '<small>ზომა ოწმახ ძირაშ დროს: $1 × $2 პიქსელ</small>',
 
-# Special:NewImages
+# Special:NewFiles
 'newimages' => 'ახალ სურათეფ',
 
 # Bad image list
