@@ -4,9 +4,9 @@
 -- from local settings.
 --
 
-GRANT DELETE,INSERT,SELECT,UPDATE ON `{$wgDBname}`.*
+GRANT DELETE,INSERT,SELECT,UPDATE,CREATE TEMPORARY TABLES ON `{$wgDBname}`.*
  TO '{$wgDBuser}'@'%' IDENTIFIED BY '{$wgDBpassword}';
-GRANT DELETE,INSERT,SELECT,UPDATE ON `{$wgDBname}`.*
+GRANT DELETE,INSERT,SELECT,UPDATE,CREATE TEMPORARY TABLES ON `{$wgDBname}`.*
  TO '{$wgDBuser}'@localhost IDENTIFIED BY '{$wgDBpassword}';
-GRANT DELETE,INSERT,SELECT,UPDATE ON `{$wgDBname}`.*
+GRANT DELETE,INSERT,SELECT,UPDATE,CREATE TEMPORARY TABLES ON `{$wgDBname}`.*
  TO '{$wgDBuser}'@localhost.localdomain IDENTIFIED BY '{$wgDBpassword}';
