@@ -112,6 +112,9 @@ var wgUploadWarningObj = {
 }
 
 function fillDestFilename(id) {
+	if (!wgUploadAutoFill) {
+		return;
+	}
 	if (!document.getElementById) {
 		return;
 	}
@@ -139,6 +142,17 @@ function fillDestFilename(id) {
 	}
 }
 
+function toggleFilenameFiller() {
+	if(!document.getElementById) return;
+	var upfield = document.getElementById('wpUploadFile');
+	var destName = document.getElementById('wpDestFile').value;
+	if (destName=='' || destName==' ') {
+		wgUploadAutoFill = true;
+	} else {
+		wgUploadAutoFill = false;
+	}
+}
+
 var wgUploadLicenseObj = {
 	
 	'responseCache' : { '' : '' },
